package com.gx.obe.server.common.json;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

import net.sf.ezmorph.object.DateMorpher;
import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import net.sf.json.JsonConfig;
import net.sf.json.util.JSONUtils;
import net.sf.json.util.PropertyFilter;

public class JsonUtil {
	
	 /**   
	 * @Title: strToObject   
	 * @Description: String 转换成 对象
	 * @param: @param <T>
	 * @param: @param str
	 * @param: @param clazz
	 * @param: @return      
	 * @return: T      
	 * @throws   
	 */  
	public static<T> T strToObject(String str,Class<T> clazz){
		if(str == null || str.isEmpty()) {
			return null;
		}
		JsonConfig jsonConfig = new JsonConfig();
      	jsonConfig.setJsonPropertyFilter(new PropertyFilter() {
            @Override
            public boolean apply(Object source, String key, Object value) {
                return false; // 返回false表示该属性会转化，true表示不转化
            }
        });
		JSONUtils.getMorpherRegistry().registerMorpher(new DateMorpher(new String[] { "yyyy-MM-dd HH:mm:ss","yyyy-MM-dd" }));
 		JSONObject jsonObject = JSONObject.fromObject(str,jsonConfig); 
	    return (T) JSONObject.toBean(jsonObject, clazz);
	}

     /**   
     * @Title: objectToStr   
     * @Description: 将对象转换成字符串
     * @param: @param <T>
     * @param: @param t
     * @param: @return      
     * @return: String      
     * @throws   
     */  
    public static<T> String objectToStr(T t){
     	JsonConfig jsonConfig = new JsonConfig();
     	jsonConfig.registerJsonValueProcessor(Date.class, new JsonDateValueProcessor());
     	jsonConfig.setJsonPropertyFilter(new PropertyFilter() {
            @Override
            public boolean apply(Object source, String key, Object value) {
                return false; // 返回false表示该属性会转化，true表示不转化
            }
        });
     	JSONObject jsonObject = JSONObject.fromObject(t,jsonConfig); 
        return jsonObject.toString();
    }
  
      /**   
     * @Title: strToList   
     * @Description: String转换List对象集合
     * @param: @param <T>
     * @param: @param str
     * @param: @param clazz
     * @param: @return      
     * @return: List<T>      
     * @throws   
     */  
    @SuppressWarnings({ "unchecked" })
    public static <T> List<T> strToList(String str, Class<T> clazz) {
		if(str == null || str.isEmpty()) {
			return new ArrayList<>();
		}
		JSONUtils.getMorpherRegistry().registerMorpher(new DateMorpher(new String[] { "yyyy-MM-dd HH:mm:ss","yyyy-MM-dd" }));
        JSONArray json = JSONArray.fromObject(str);
        JSONObject object = null;
        T t = null;
        List<T> list = new ArrayList<>();
        for (int i = 0; i < json.size(); i++) {
            object = JSONObject.fromObject(json.get(i));
            t = (T) JSONObject.toBean(object, clazz);
            list.add(t);
        }
        return list;
    }
    
     /**   
     * @Title: strToObject   
     * @Description: 为json的返回值中的对象转换
     * @param: @param <T>
     * @param: @param result
     * @param: @param clazz
     * @param: @param classMap
     * @param: @return      
     * @return: T      
     * @throws   
     */  
    @SuppressWarnings("unchecked")
	public static<T> T strToObject(String result,Class<T> clazz,Map<String, Class<?>> classMap){  	
		JSONUtils.getMorpherRegistry().registerMorpher(new DateMorpher(new String[] { "yyyy-MM-dd HH:mm:ss","yyyy-MM-dd"}));
    	JSONObject jsonObj = JSONObject.fromObject(result); 
     	return (T) JSONObject.toBean(jsonObj,clazz, classMap); 	
     }
    
    
    @SuppressWarnings("unchecked")
	public static <T> List<T> StrToCollection(String result,Class<T> clazz){
		JSONUtils.getMorpherRegistry().registerMorpher(new DateMorpher(new String[] { "yyyy-MM-dd HH:mm:ss","yyyy-MM-dd" }));
    	JSONArray jsonArray = JSONArray.fromObject(result);
     	return (List<T>)JSONArray.toCollection(jsonArray,clazz);
    }
    
    @SuppressWarnings("unchecked")
	public static Map<String,String> strToMap(String result){
    	JSONObject  jasonObject = JSONObject.fromObject(result);
    	return (Map<String, String>)jasonObject;
     }
        
    public static String obejctListToStr(List<?> list) {
    	JSONArray listArray = JSONArray.fromObject(list);
		return listArray.toString(); 	
    }
    
    public static String obejctListToStr(String obj1 ,String obj2) {
    	JSONObject jsonObj1 = JSONObject.fromObject(obj1); 
    	JSONObject jsonObj2 = JSONObject.fromObject(obj2); 
    	JSONObject jsonThree = new JSONObject();  
    	jsonThree.putAll(jsonObj1);  
    	jsonThree.putAll(jsonObj2);  
		return jsonThree.toString(); 	
    }
    
}