package com.gx.obe.server.common.vo;

 
import java.io.Serializable;

import lombok.ToString;

/**  
 * @Title:  Result.java   
 * @Package com.gx.obe.server.controllers.details   
 * @Description:    标准返回对象结构体  
 * @author: XiaoMaPro     
 * @date:   2019年4月25日 下午1:46:02   
 * @version V1.0 
 * @Copyright: 2018 - 2019 www.myspro.com Inc. All rights reserved. 
 *  
 */
@ToString
public class Result<T> implements Serializable{
	
	public static final int SUCCESS = 0;
	
	public static final int FAIL = 1;
	
	private static final long serialVersionUID = 1L;
	
	private  String msg = "success";

	private int code = SUCCESS;

	private T data;

	public Result() {
		super();
	}

	public Result(T data) {
		super();
		this.data = data;
	}

	public Result(T data, String msg) {
		super();
		this.data = data;
		this.msg = msg;
	}

	public Result(T data, String msg ,int code) {
		super();
		this.data = data;
		this.code = code;
		this.msg = msg;
	}
	public Result(Throwable e) {
		super();
		this.msg = e.getMessage();
		this.code = FAIL;
	}

	public String getMsg() {
		return msg;
	}

	public void setMsg(String msg) {
		this.msg = msg;
	}

	public int getCode() {
		return code;
	}

	public void setCode(int code) {
		this.code = code;
	}

	public T getData() {
		return data;
	}

	public void setData(T data) {
		this.data = data;
	}
	
	public static <T> Result<T> ok() {
		return restResult(null, SUCCESS, "success");
	}

	public static <T> Result<T> ok(T data) {
		return restResult(data, SUCCESS, null);
	}

	public static <T> Result<T> ok(T data, String msg) {
		return restResult(data, SUCCESS, msg);
	}

	public static <T> Result<T> failed() {
		return restResult(null, FAIL, null);
	}

	public static <T> Result<T> failed(String msg) {
		return restResult(null,FAIL, msg);
	}

	public static <T> Result<T> failed(T data) {
		return restResult(data, FAIL, null);
	}

	public static <T> Result<T> failed(T data, String msg) {
		return restResult(data, FAIL, msg);
	}

	private static <T> Result<T> restResult(T data, int code, String msg) {
		Result<T> apiResult = new Result<>();
		apiResult.setCode(code);
		apiResult.setData(data);
		apiResult.setMsg(msg);
		return apiResult;
	}
}
