package com.gx.obe.server.im.serverthread;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.IOException;
import java.net.BindException;
import java.net.ServerSocket;
import java.net.Socket;

import org.slf4j.Logger;

import com.gx.obe.server.im.ChatConstants;
import com.gx.obe.server.im.IMConstants;
import com.gx.obe.server.im.SendFileParam;
import com.gx.obe.server.im.enumeration.PropertieEnum;
import com.gx.obe.server.im.serverthread.SendFileThread.ServerSendFileListener;
import com.gx.obe.server.im.util.IMPropertiesUtil;
/**<pre>
 * @Description:离线文件会发给服务器暂存，服务器接收完成以后，判断接收文件的客户端在线否，在线就立即通知他接收
 * 直到他拒绝或接收完成以后，才会删除数据库记录(此类只完成接收动作，完成以后会开启一个线程让在线者接收)
 * @Description:
 * @author guoyr
 * </pre>
 */
public class SendFileByServerThread implements ServerFileThread{
        private Logger LOG = org.slf4j.LoggerFactory.getLogger(SendFileByServerThread.class);
        private SendFilter sendFilter;
        private ServerSocket serverSocket;
       
        private int thisPort;
        private Thread thread;
        private Socket receiveSocket;
        private Socket sendSocket;
        private SendFileThread sendFileThread;
        private SendFileParam params;
        private long threadId = 0;
        private ServerSendFileListener serverSendFileListener;
		
		public SendFileByServerThread(SendFileParam params, ServerSendFileListener serverSendFileListener, SendFilter sendFilter){
			this.params = params;
			this.sendFilter = sendFilter;
			this.serverSendFileListener= serverSendFileListener;
		}
		public void start(){
			thread = new Thread(this);
			thread.setName("服务器中转发送文件");
			threadId = params.getThreadId();
			params.setThreadId(threadId);
			thread.start();
		}
		public void run(){
			try {
				Thread.sleep(500);
				boolean createChangeServer = false;
				 while( !createChangeServer ){
					 thisPort = ChatConstants.SEND_FILE_PORT ++ ;
			            try { 
			                serverSocket = new ServerSocket(thisPort);
			                createChangeServer = true;
			            } catch (BindException e) {
			            	LOG.error(e.getMessage() + ChatConstants.SEND_FILE_PORT + "端口已被占用！", e);
			            	continue;
			            } catch (IOException e) {
			            	LOG.error(e.getMessage() + thisPort+ "端口已被占用！", e);
			            	stop();
			                return;
			            } 
			        } 
			        if (ChatConstants.SEND_FILE_PORT > Integer.parseInt(IMPropertiesUtil.getProperty(PropertieEnum.FILE_RECEIVE_MAX_PORT, "7999")) ){
			        	ChatConstants.SEND_FILE_PORT = Integer.parseInt(IMPropertiesUtil.getProperty(PropertieEnum.FILE_RECEIVE_PORT, "7999"));
			        };
			        if(null != serverSocket){
			        	// 告诉接收方，有服务器转发的文件需要接nh
			        	SendFileParam receiveParams = SendFileParam.copy(params);
			        	receiveParams.setOrder(IMConstants.SEND_FILE_REQUEST);
			        	receiveParams.setSendPort(thisPort);
			        	
			        	// 告诉文件接收方，有服务器发送文件请求
			        	sendFilter.sendFileByServerRequest(receiveParams);
			        	
			        	// 等待接收方发连接服务器准备接收文件
			        	receiveSocket = serverSocket.accept();
			        	
			        	// 等待发送方连接到服务器并开始发送
			        	sendSocket = serverSocket.accept();
			        	sendFileThread = new SendFileThread();
			        	sendFileThread.start();
			        }
			} catch (Exception ex) {
				stop();
			}
		}
		
        class SendFileThread implements Runnable{
        	private BufferedOutputStream bos;
    		private BufferedInputStream bis = null;
//    		private BufferedOutputStream sendBos;
    		private Thread thread;
    		public void start(){
    			
    			thread = new Thread(this);
    			thread.start();
    		}
    		public void stopSend(){
    			thread = null;
    			bos = null;
    			bis = null;
    		}
			public void run() {
				boolean sendComplate = false;
				while(null != thread && !sendComplate && null != receiveSocket && null != sendSocket){
					try {
//						sendBos = new BufferedOutputStream(sendSocket.getOutputStream());
//						sendBos.write("beginSendFile".getBytes());
						bos = new BufferedOutputStream(receiveSocket.getOutputStream());
						bis = new BufferedInputStream(sendSocket.getInputStream());
						byte[] bs = new byte[ChatConstants.MAX_LENGTH];
	                    int len = bis.read(bs);
	                    while( len != -1 ){
	                        bos.write(bs,0, len);
	                        bos.flush();
	                        len = bis.read(bs);
	                    } 
	                    sendComplate = true;
	                    break;
					} catch (IOException e) {
//						LOG.error(e.getMessage());
					} 
					try {
						Thread.sleep(500);
					} catch (InterruptedException e) {
					}
				}
				 try {
					 if(null != bis){
						 bis.close();
					 }
					 bis = null;
				} catch (IOException e) {
				}
                 try {
                	 if(null != bos){
                		 bos.close();
                	 }
                	 bos = null;
				} catch (IOException e) {
				}
				stop();
			}
        	
        }
		public interface SendFilter{
			public void sendFileByServerRequest(SendFileParam params);
			public void online(String fileName, String sendId, String receiveId, int port);
		}
		
		public void stop(){
			thread = null;
			serverSendFileListener.removeServerFileThread(this);
			if(null != sendFileThread){
				sendFileThread.stopSend();
			}
			try {
				if(null != serverSocket){
					serverSocket.close();
				}
				serverSocket = null;
			} catch (IOException e) {
			}
			
		}
		public long getThreadId() {
			return threadId;
		}
		public void deleteFile() {
			
		}
		public boolean isStop() {
			return null == thread;
		}
	}
