package com.gx.obe.server.management.boq.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.boq.dao.ObeAppraisalPriceMapper;
import com.gx.obe.server.management.boq.entity.ObeAppraisalPrice;
import com.gx.obe.server.management.boq.service.ObeAppraisalPriceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * @author mazc
 * @Description:
 */
@Service
@Transactional
public class ObeAppraisalPriceServiceImpl extends ServiceImpl<ObeAppraisalPriceMapper, ObeAppraisalPrice> implements ObeAppraisalPriceService {

    @Autowired
    private ObeAppraisalPriceMapper obeAppraisalPriceMapper;

    /**
     * @param ObeAppraisalPriceList
     * @Description: 批量更新
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer updateByBatch(List<ObeAppraisalPrice> ObeAppraisalPriceList) {
        return obeAppraisalPriceMapper.updateBatchList(ObeAppraisalPriceList);
    }

    /**
     * @param ObeAppraisalPriceList
     * @Description: 批量插入
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer insertByBatch(List<ObeAppraisalPrice> ObeAppraisalPriceList) {
        return obeAppraisalPriceMapper.insertByBatch(ObeAppraisalPriceList);
    }

    /**
     * @param ObeAppraisalPrice
     * @param attributes
     * @Description: 指定字段修改
     * @author chenxw
     */
    @Override
    public boolean updateAssignProperty(ObeAppraisalPrice ObeAppraisalPrice, String[] attributes) {
        return obeAppraisalPriceMapper.updateAssignProperty(ObeAppraisalPrice, attributes) > 0;
    }

    /**
     * @param ObeAppraisalPriceList
     * @param attributes
     * @Description: 批量指定字段修改
     * @author chenxw
     */
    @Override
    public Integer batchUpdateProperty(List<ObeAppraisalPrice> ObeAppraisalPriceList, String[] attributes) {
        return obeAppraisalPriceMapper.batchUpdateProperty(ObeAppraisalPriceList, attributes);
    }

    /**
     * @param ObeAppraisalPriceList
     * @param attributes
     * @return
     * @Description: 批量添加或跟新
     * @author chenxw
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer batchSaveOrUpdate(List<ObeAppraisalPrice> ObeAppraisalPriceList, String[] attributes) {
        List<ObeAppraisalPrice> insertObeAppraisalPriceList = new ArrayList<>();
        List<ObeAppraisalPrice> updateObeAppraisalPriceList = new ArrayList<>();
        for (ObeAppraisalPrice ObeAppraisalPrice : ObeAppraisalPriceList) {
            if (StringUtils.isEmpty(ObeAppraisalPrice.getId())) {
                ObeAppraisalPrice.setId(IDUtils.getId());
                insertObeAppraisalPriceList.add(ObeAppraisalPrice);
            } else {
                updateObeAppraisalPriceList.add(ObeAppraisalPrice);
            }
        }
        int count = 0;
        if (insertObeAppraisalPriceList.size() > 0) {
            count += obeAppraisalPriceMapper.insertByBatch(insertObeAppraisalPriceList);
        }
        if (updateObeAppraisalPriceList.size() > 0) {
            count += obeAppraisalPriceMapper.batchUpdateProperty(updateObeAppraisalPriceList, attributes);
        }
        return count;
    }

    /**
     * @Description:  根据工程Id，获得暂估价
     * @author guoyr
     * @param projectId
     * @return AppraisalPrice
     */
    public List<ObeAppraisalPrice> getAppraisalPriceListByProjectId(String projectId){
        return obeAppraisalPriceMapper.getAppraisalPriceListByProjectId(projectId);
    }

}
