package com.gx.obe.server.management.boq.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.boq.dao.ObeDayWorksMapper;
import com.gx.obe.server.management.boq.entity.ObeDayWorks;
import com.gx.obe.server.management.boq.service.ObeDayWorksService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * @author mazc
 * @Description:
 */
@Service
@Transactional
public class ObeDayWorksServiceImpl extends ServiceImpl<ObeDayWorksMapper, ObeDayWorks> implements ObeDayWorksService {

    @Autowired
    private ObeDayWorksMapper obeDayWorksMapper;

    /**
     * @param ObeDayWorksList
     * @Description: 批量更新
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer updateByBatch(List<ObeDayWorks> ObeDayWorksList) {
        return obeDayWorksMapper.updateBatchList(ObeDayWorksList);
    }

    /**
     * @param ObeDayWorksList
     * @Description: 批量插入
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer insertByBatch(List<ObeDayWorks> ObeDayWorksList) {
        return obeDayWorksMapper.insertByBatch(ObeDayWorksList);
    }

    /**
     * @param ObeDayWorks
     * @param attributes
     * @Description: 指定字段修改
     * @author chenxw
     */
    @Override
    public boolean updateAssignProperty(ObeDayWorks ObeDayWorks, String[] attributes) {
        return obeDayWorksMapper.updateAssignProperty(ObeDayWorks, attributes) > 0;
    }

    /**
     * @param ObeDayWorksList
     * @param attributes
     * @Description: 批量指定字段修改
     * @author chenxw
     */
    @Override
    public Integer batchUpdateProperty(List<ObeDayWorks> ObeDayWorksList, String[] attributes) {
        return obeDayWorksMapper.batchUpdateProperty(ObeDayWorksList, attributes);
    }

    /**
     * @param ObeDayWorksList
     * @param attributes
     * @return
     * @Description: 批量添加或跟新
     * @author chenxw
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer batchSaveOrUpdate(List<ObeDayWorks> ObeDayWorksList, String[] attributes) {
        List<ObeDayWorks> insertObeDayWorksList = new ArrayList<>();
        List<ObeDayWorks> updateObeDayWorksList = new ArrayList<>();
        for (ObeDayWorks ObeDayWorks : ObeDayWorksList) {
            if (StringUtils.isEmpty(ObeDayWorks.getId())) {
                ObeDayWorks.setId(IDUtils.getId());
                insertObeDayWorksList.add(ObeDayWorks);
            } else {
                updateObeDayWorksList.add(ObeDayWorks);
            }
        }
        int count = 0;
        if (insertObeDayWorksList.size() > 0) {
            count += obeDayWorksMapper.insertByBatch(insertObeDayWorksList);
        }
        if (updateObeDayWorksList.size() > 0) {
            count += obeDayWorksMapper.batchUpdateProperty(updateObeDayWorksList, attributes);
        }
        return count;
    }

    /**
     * @param projectId
     * @return DayWorks
     * @Description: 根据工程Id，获得计日工信息。
     * @author guoyr
     */
    public List<ObeDayWorks> getDayWorksListByProjectId(String projectId) {
        return obeDayWorksMapper.getDayWorksListByProjectId(projectId);
    }

}
