package com.gx.obe.server.management.boq.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.boq.dao.ObeSupplyMaterialDetailMapper;
import com.gx.obe.server.management.boq.entity.ObeSupplyMaterialDetail;
import com.gx.obe.server.management.boq.service.ObeSupplyMaterialDetailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * @author mazc
 * @Description:
 */
@Service
@Transactional
public class ObeSupplyMaterialDetailServiceImpl extends ServiceImpl<ObeSupplyMaterialDetailMapper, ObeSupplyMaterialDetail> implements ObeSupplyMaterialDetailService {

    @Autowired
    private ObeSupplyMaterialDetailMapper obeSupplyMaterialDetailMapper;

    /**
     * @param ObeSupplyMaterialDetailList
     * @Description: 批量更新
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer updateByBatch(List<ObeSupplyMaterialDetail> ObeSupplyMaterialDetailList) {
        return obeSupplyMaterialDetailMapper.updateBatchList(ObeSupplyMaterialDetailList);
    }

    /**
     * @param ObeSupplyMaterialDetailList
     * @Description: 批量插入
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer insertByBatch(List<ObeSupplyMaterialDetail> ObeSupplyMaterialDetailList) {
        return obeSupplyMaterialDetailMapper.insertByBatch(ObeSupplyMaterialDetailList);
    }

    /**
     * @param ObeSupplyMaterialDetail
     * @param attributes
     * @Description: 指定字段修改
     * @author chenxw
     */
    @Override
    public boolean updateAssignProperty(ObeSupplyMaterialDetail ObeSupplyMaterialDetail, String[] attributes) {
        return obeSupplyMaterialDetailMapper.updateAssignProperty(ObeSupplyMaterialDetail, attributes) > 0;
    }

    /**
     * @param ObeSupplyMaterialDetailList
     * @param attributes
     * @Description: 批量指定字段修改
     * @author chenxw
     */
    @Override
    public Integer batchUpdateProperty(List<ObeSupplyMaterialDetail> ObeSupplyMaterialDetailList, String[] attributes) {
        return obeSupplyMaterialDetailMapper.batchUpdateProperty(ObeSupplyMaterialDetailList, attributes);
    }

    /**
     * @param ObeSupplyMaterialDetailList
     * @param attributes
     * @return
     * @Description: 批量添加或跟新
     * @author chenxw
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer batchSaveOrUpdate(List<ObeSupplyMaterialDetail> ObeSupplyMaterialDetailList, String[] attributes) {
        List<ObeSupplyMaterialDetail> insertObeSupplyMaterialDetailList = new ArrayList<>();
        List<ObeSupplyMaterialDetail> updateObeSupplyMaterialDetailList = new ArrayList<>();
        for (ObeSupplyMaterialDetail ObeSupplyMaterialDetail : ObeSupplyMaterialDetailList) {
            if (StringUtils.isEmpty(ObeSupplyMaterialDetail.getId())) {
                ObeSupplyMaterialDetail.setId(IDUtils.getId());
                insertObeSupplyMaterialDetailList.add(ObeSupplyMaterialDetail);
            } else {
                updateObeSupplyMaterialDetailList.add(ObeSupplyMaterialDetail);
            }
        }
        int count = 0;
        if (insertObeSupplyMaterialDetailList.size() > 0) {
            count += obeSupplyMaterialDetailMapper.insertByBatch(insertObeSupplyMaterialDetailList);
        }
        if (updateObeSupplyMaterialDetailList.size() > 0) {
            count += obeSupplyMaterialDetailMapper.batchUpdateProperty(updateObeSupplyMaterialDetailList, attributes);
        }
        return count;
    }

    /**
     * @param projectId
     * @return
     * @Description: 根据工程项目id获取招标人供应材料设备明细列表
     * @author chenxw
     */
    public List<ObeSupplyMaterialDetail> getSupplyMaterialDetailListByProjectId(String projectId) {
        return obeSupplyMaterialDetailMapper.getSupplyMaterialDetailListByProjectId(projectId);
    }

}
