package com.gx.obe.server.management.check.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.check.dao.CheckResultMapper;
import com.gx.obe.server.management.check.entity.CheckResult;
import com.gx.obe.server.management.check.service.CheckResultService;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
@Transactional
public class CheckResultServiceImpl extends ServiceImpl<CheckResultMapper, CheckResult> implements CheckResultService {

	@Autowired
	private CheckResultMapper checkResultMapper;
	
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeCheckResultList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch (List<CheckResult> ObeCheckResultList){
		return checkResultMapper.updateBatchList(ObeCheckResultList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeCheckResultList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch (List<CheckResult> ObeCheckResultList){
		return checkResultMapper.insertByBatch(ObeCheckResultList);
	}

	/** 
	 * @Description: 删除清标检查结果
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	@Override
	public int deleteStepByTenderId(String tenderId) {
		QueryWrapper<CheckResult> queryWrapper = new QueryWrapper<CheckResult>();
		queryWrapper.lambda().eq(CheckResult::getTenderId, tenderId);
		return checkResultMapper.delete(queryWrapper);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public int saveBoqCheckResult(String tenderId, String userId, String checkItemId,List<CheckResult> checkResultList) {
		checkResultMapper.deleteBoqCheckResult(tenderId, userId, checkItemId);
		return checkResultMapper.insertByBatch(checkResultList);
	}

	@Override
	public int getQueryCount(String tenderId, String userId, String checkItemId) {
		QueryWrapper<CheckResult> queryWrapper = new QueryWrapper<CheckResult>();
		queryWrapper.select(CheckResult.CHECK_RESULT_ID);
		queryWrapper.lambda().eq(CheckResult::getTenderId, tenderId)
		.eq(CheckResult::getUserId, userId)
		.eq(CheckResult::getCheckItemId, checkItemId);
		return checkResultMapper.selectList(queryWrapper).size();
		
	}

	@Override
	public CheckResult getCheckResultByCondition(String tenderId, String userId, String supplierId, String checkItemId,
			String stepId) {
		QueryWrapper<CheckResult> queryWrapper = new QueryWrapper<CheckResult>();
		queryWrapper.lambda().eq(CheckResult::getTenderId, tenderId)
		.eq(CheckResult::getSupplierId, supplierId)
		.eq(CheckResult::getUserId, userId)
		.eq(CheckResult::getCheckItemId, checkItemId);
		if(StringUtils.isNotEmpty(stepId)) {
			queryWrapper.lambda().eq(CheckResult::getStepId, stepId);			
		}
		return checkResultMapper.selectOne(queryWrapper);
	}

	/** 
	 * @Description: 删除评审记录结果
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public int deleteCheckResult(String tenderId, String stepId) {
		QueryWrapper<CheckResult> queryWrapper = new QueryWrapper<CheckResult>();
		queryWrapper.lambda().eq(CheckResult::getTenderId, tenderId)
							 .eq(CheckResult::getStepId, stepId);
		return checkResultMapper.delete(queryWrapper);
	}

	/**
	 * @Description: 获取清单检查结果
	 * @author mazc
	 * @param tenderId
	 * @param checkItemId
	 * @param supplierIds
	 * @return
	 */
	public List<CheckResult> getCheckResultByDictionaryValueId(String tenderId, String checkItemId, List<String> supplierIds) {
		return checkResultMapper.getCheckResultByDictionaryValueId(tenderId, checkItemId, supplierIds);
	}

}
