package com.gx.obe.server.management.dictionary.controller;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.management.dictionary.entity.Machine;
import com.gx.obe.server.management.dictionary.service.MachineService;
import com.gx.obe.server.management.vo.Condition;

import lombok.AllArgsConstructor;
/** 
 * @Description: 
 * @author mazc 
 */
@RestController
@AllArgsConstructor
@RequestMapping("/machine")
public class MachineController extends BaseController<MachineService,Machine>{
	@Autowired
	public MachineService machineServices;
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param obeMachineList 
	 */
	@PostMapping("/insertByBatch")
	public int insertByBatch(@RequestBody List<Machine> obeMachineList) {
		return machineServices.insertByBatch(obeMachineList);
	}
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param obeMachineList 
	 */
	@PostMapping("/updateByBatch")
	public int updateByBatch(@RequestBody List<Machine> obeMachineList) {
		return machineServices.updateByBatch(obeMachineList);
	}

	/**
	 * @Description: 获得评标机位集合
	 * @author mazc
	 * @param tenderId 项目ID
	 * @param isUsed 是否使用
	 * @param machineType 类型
	 * @return List<Machine>
	 */
	@GetMapping("/getProjectMachineList")
	public List<Machine> getProjectMachineList(String tenderId, String isUsed, String machineType){
		return machineServices.getProjectMachineList(tenderId, isUsed, machineType);
	}
	
	/**
	 * @Description: 获得当前项目下已登录的机位
	 * @author mazc
	 * @param tenderId 项目
	 * @param loginTime 登录时间
	 * @return
	 */
	@GetMapping("/getProjectLoginedMachineList")
	public List<Machine> getProjectLoginedMachineList(String tenderId, Date loginTime){
		return machineServices.getProjectLoginedMachineList(tenderId, loginTime);
	}
	
	/**
	 * @Description: 获得指定评标室内的机位列表
	 * @author mazc
	 * @param roomeId
	 * @return
	 */
	@GetMapping("/getEvaluationRoomMachineList")
	public List<Machine> getEvaluationRoomMachineList(String roomeId){
		return machineServices.getEvaluationRoomMachineList(roomeId);
	}
	
	/**
	 * @Description: 批量保存已申请机位信息
	 * @author mazc
	 * @param list
	 * @return
	 */
	@PostMapping("/saveMachineList")
	public int saveMachineList(List<Machine> list){
		return machineServices.saveMachineList(list);
	}
	
	/** 
	 * @Description: 删除评标室的机位
	 * @author mazc
	 * @param roomId
	 * @return 
	 */
	@GetMapping("/deleteEvaluationRoomMachine")
	public int deleteEvaluationRoomMachine(String roomId){
		return machineServices.deleteEvaluationRoomMachine(roomId);	
	}
	
	/**
	 * @Description:  验证是否已经申请过该 机位
	 * @author mazc
	 * @param machineMac
	 * @param machineIp
	 * @param useStatus
	 * @return 
	 */
	@GetMapping("/isExist")
	public boolean isExist(String machineMac ,String machineIp,String useStatus){
		return machineServices.isExist(machineMac, machineIp, useStatus).size() > 0;
	}
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param machine
	 * @return 
	 */
	@PostMapping("/applyMachine")
	public Machine applyMachine(@RequestBody Machine machine){
		return machineServices.saveOrUpdateReturn(machine);
	}
	/**
	 * @Description: 
	 * @author mazc
	 * @param machine
	 * @return 
	 */
	@PostMapping("/saveOrUpdateReturn")
	public Machine saveOrUpdateReturn(@RequestBody Machine machine){
		return machineServices.saveOrUpdateReturn(machine);
	}
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param machineMac
	 * @param useStatus
	 * @return 
	 */
	@GetMapping("/getEvalRoomIdByMachineMacAndUseStatus")
	public List<Object> getEvalRoomIdByMachineMacAndUseStatus(String machineMac, String useStatus){
		return machineServices.getEvalRoomIdByMachineMacAndUseStatus(machineMac, useStatus);
	}
	
	@GetMapping("/getMachineByUseStatusAndOrderby")
	public List<Machine> getMachineByUseStatusAndOrderby(String useStatus){
		return machineServices.getMachineByUseStatusAndOrderby(useStatus);
	}
	
	@GetMapping("/getMachineByMacOrNotEQ")
	public Machine getMachineByMacOrNotEQ(String machineMac,String id){
		return machineServices.getMachineByMacOrNotEQ(machineMac, id);
	}
	@GetMapping("/getEvalRoomIdByMachineNameAndEvalRoomId")
	public List<Object> getEvalRoomIdByMachineNameAndEvalRoomId(String machineName, String evalRoomId,String id){
		return machineServices.getEvalRoomIdByMachineNameAndEvalRoomId(machineName, evalRoomId, id);
	}
	
	@PostMapping("/updateCondition")
	public int updateCondition(@RequestBody Condition condition){
		return machineServices.updateCondition(condition);
	}
	
}