package com.gx.obe.server.management.dictionary.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.agent.ProjectTemplateAgent;
import com.gx.obe.server.common.enumeration.EvaluationStepEnum;
import com.gx.obe.server.common.utils.CollectionUtils;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.common.vo.ProjectTypeVo;
import com.gx.obe.server.management.dictionary.dao.ProjectTemplateMapper;
import com.gx.obe.server.management.dictionary.entity.ProjectTemplate;
import com.gx.obe.server.management.dictionary.service.ProjectTemplateService;
import com.gx.obe.server.management.evaluation.service.EvaluationStepService;
import com.gx.obe.server.management.project.dao.TenderProjectMapper;
import com.gx.obe.server.management.project.entity.TenderProject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.File;
import java.nio.file.Paths;
import java.util.*;

/**
 * @author mazc
 * @Description:
 */
@Service
@Transactional
public class ProjectTemplateServiceImpl extends ServiceImpl<ProjectTemplateMapper, ProjectTemplate> implements ProjectTemplateService {

	@Autowired
	private TenderProjectMapper tenderProjectMapper;

	@Autowired
	private ProjectTemplateMapper projectTemplateMapper;

	@Autowired
	private EvaluationStepService evaluationStepService;

	@Value("${upload.templateFolder}")
	private String templateFolder;

	/**
	 * @param ObeProjectTemplateList
	 * @Description: 批量更新
	 * @author mazc
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch(List<ProjectTemplate> ObeProjectTemplateList) {
		return projectTemplateMapper.updateBatchList(ObeProjectTemplateList);
	}

	/**
	 * @param ObeProjectTemplateList
	 * @Description: 批量插入
	 * @author mazc
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch(List<ProjectTemplate> ObeProjectTemplateList) {
		return projectTemplateMapper.insertByBatch(ObeProjectTemplateList);
	}

	/**
	 * @param ObeProjectTemplate
	 * @param attributes
	 * @Description: 指定字段修改
	 * @author chenxw
	 */
	@Override
	public boolean updateAssignProperty(ProjectTemplate ObeProjectTemplate, String[] attributes) {
		return projectTemplateMapper.updateAssignProperty(ObeProjectTemplate, attributes) > 0;
	}

	/**
	 * @param ObeProjectTemplateList
	 * @param attributes
	 * @Description: 批量指定字段修改
	 * @author chenxw
	 */
	@Override
	public Integer batchUpdateProperty(List<ProjectTemplate> ObeProjectTemplateList, String[] attributes) {
		return projectTemplateMapper.batchUpdateProperty(ObeProjectTemplateList, attributes);
	}

	/**
	 * @param ObeProjectTemplateList
	 * @param attributes
	 * @return
	 * @Description: 批量添加或跟新
	 * @author chenxw
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer batchSaveOrUpdate(List<ProjectTemplate> ObeProjectTemplateList, String[] attributes) {
		List<ProjectTemplate> insertObeProjectTemplateList = new ArrayList<>();
		List<ProjectTemplate> updateObeProjectTemplateList = new ArrayList<>();
		for (ProjectTemplate ObeProjectTemplate : ObeProjectTemplateList) {
			if (StringUtils.isEmpty(ObeProjectTemplate.getId())) {
				ObeProjectTemplate.setId(IDUtils.getId());
				insertObeProjectTemplateList.add(ObeProjectTemplate);
			} else {
				updateObeProjectTemplateList.add(ObeProjectTemplate);
			}
		}
		int count = 0;
		if (insertObeProjectTemplateList.size() > 0) {
			count += projectTemplateMapper.insertByBatch(insertObeProjectTemplateList);
		}
		if (updateObeProjectTemplateList.size() > 0) {
			count += projectTemplateMapper.batchUpdateProperty(updateObeProjectTemplateList, attributes);
		}
		return count;
	}

	/**
	 * @Description: 获取所有模板
	 * @author chenxw
	 * @return
	 */
	@Override
	public List<ProjectTemplate> getAllList() {
		return projectTemplateMapper.selectList(new QueryWrapper<>());
	}

	/**
	 * @Description: 根据项目id及模板类型获取列表
	 * @author chenxw
	 * @param tenderId
	 * @param templateType
	 * @return
	 */
	@Override
	public List<ProjectTemplate> getListByTenderIdAndTemplateType(String tenderId, String templateType) {
		boolean fixedFactor = CollectionUtils.isNotNull(evaluationStepService.getEvaluationStepListByType(tenderId, EvaluationStepEnum.FIXED_FACTOR));
		String agentName = Optional.ofNullable(tenderId).map(tenderProjectMapper::selectById).map(TenderProject::getAgentName).orElse("");
		List<ProjectTemplate> list = ProjectTemplateAgent.init(this)
				.filter(ProjectTemplate::getTemplateType, t -> templateType == null || templateType.equals(t))
				.filterType(ProjectTypeVo::isFixedFactor, t -> fixedFactor == t)
				.filterType(ProjectTypeVo::getAgentKeyList, t -> Objects.nonNull(t) && t.contains(agentName))
				.get();
		if (!list.isEmpty()) return list;
		return ProjectTemplateAgent.init(this)
				.filterType(ProjectTypeVo::isDefaultType, t -> t)
				.get();
	}

	/**
	 * @Description: 删除项目模板
	 * @author chenxw
	 * @param projectTemplate
	 * @return
	 */
	@Override
	public boolean deleteProjectTemplate(ProjectTemplate projectTemplate) {
		File file = new File(Paths.get(templateFolder + "/" + projectTemplate.getTemplateFileName()).toString());
		if (file.exists() && !file.delete()) {
			return false;
		}
		return projectTemplateMapper.deleteById(projectTemplate.getId()) > 0;
	}

	/**
	 * @Description: 获取最晚修改时间
	 * @author chenxw
	 * @return
	 */
	@Override
	public Date getLatestModifyTime() {
		return projectTemplateMapper.getLatestModifyTime();
	}
}
