package com.gx.obe.server.management.dictionary.service.impl;

import java.util.List;

import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.management.dictionary.dao.StructMapper;
import com.gx.obe.server.management.dictionary.entity.Struct;
import com.gx.obe.server.management.dictionary.service.StructService;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
@Transactional
public class StructServiceImpl extends ServiceImpl<StructMapper, Struct> implements StructService {

	@Autowired
	private StructMapper structMapper;
	
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeStructList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch (List<Struct> ObeStructList){
		return structMapper.updateBatchList(ObeStructList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeStructList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch (List<Struct> ObeStructList) {
		 for (Struct struct : ObeStructList)
			 if (StringUtils.isEmpty(struct.getId()))
				 struct.setId(IDUtils.getId());
		 return structMapper.insertByBatch(ObeStructList);
	 }

	/** 
	 * @Description: 根据供应商id和指标id获取结构化数据列表
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @param factorId
	 * @return 
	 */
	@Override
	public List<Struct> getStructBySupplierIdAndFactorIdList(String tenderId, String supplierId, String factorId) {
		return structMapper.getStructBySupplierIdAndFactorIdList(tenderId, supplierId, factorId);
	}

	@Override
	public boolean updateAssignProperty(Struct struct) {
		return structMapper.updateById(struct) > 0;
	}
	

}
