package com.gx.obe.server.management.evaluation.controller;

import java.util.Date;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.common.json.EntityUtill;
import com.gx.obe.server.common.log.OperationType;
import com.gx.obe.server.common.log.SysLogAnnotation;
import com.gx.obe.server.common.vo.RequestBodyEntity;
import com.gx.obe.server.management.evaluation.entity.BidPrice;
import com.gx.obe.server.management.evaluation.entity.BidPriceResult;
import com.gx.obe.server.management.evaluation.service.BidPriceResultService;
import com.gx.obe.server.management.project.entity.TenderProject;
import com.gx.obe.server.management.supplier.entity.SupplierOpeningResult;
import com.gx.obe.server.management.vo.SaveSubBidPriceResultVo;
import com.gx.obe.server.management.vo.SaveSupplierBidPriceResultVo;
import com.gx.obe.server.management.vo.SaveSupplierInputBidPriceResultVo;
import com.gx.obe.server.management.vo.SaveSupplierInputEvaluationPriceResultVo;
import com.gx.obe.server.management.vo.UpdateAssignPropertyVo;

import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;
/** 
 * @Description: 
 * @author mazc 
 */
@Api(tags = "开标一览表")
@RestController
@AllArgsConstructor
@RequestMapping("/bidPriceResult")
public class BidPriceResultController extends BaseController<BidPriceResultService,BidPriceResult>{
	
	@Autowired
	private BidPriceResultService bidPriceResultService;
	
	/**
	 * @Description: 获得供应商开标一览表
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	@GetMapping("/getBidPriceResultTableList")
	public List<BidPriceResult> getBidPriceResultTableList(String tenderId, String supplierId){
		return bidPriceResultService.getBidPriceResultTableList(tenderId, supplierId);
	}
	
	/**
	 * @Description: 获得供应商的分项报价结果
	 * @author mazc
	 * @param tenderId
	 * @param bidPriceId
	 * @return 
	 */
	@GetMapping("/findBidPriceResultList")
	public List<BidPriceResult> findBidPriceResultList(String tenderId, String bidPriceId){
		return bidPriceResultService.findBidPriceResultList(tenderId, bidPriceId);
	}

	
	/**
	 * @Description: 获得分项报价结果
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	@GetMapping("/getBidPriceResultList")
	public List<BidPriceResult> getBidPriceResultList(String tenderId){
		return bidPriceResultService.getBidPriceResultList(tenderId);
	}
	
	
	/**
	 * @Description: 获得唱标的分项报价
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	@GetMapping("/getSingBidPriceResultList")
	public List<BidPriceResult> getSingBidPriceResultList(String tenderId){
		return bidPriceResultService.getSingBidPriceResultList(tenderId);
	}
	
	/**
	 * @Description: 获得供应商的分项报价
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	@GetMapping("/getSupplierBidPriceResultList")
	public List<BidPriceResult> getSupplierBidPriceResultList(String tenderId, String supplierId){
		return bidPriceResultService.getSupplierBidPriceResultList(tenderId, supplierId);
	}
	
	/**
	 * @Description: 获得供应商的分项报价
	 * @author mazc
	 * @param bidPriceId
	 * @param supplierId
	 * @return 
	 */
	@GetMapping("/getSupplierBidPriceResult")
	public BidPriceResult getSupplierBidPriceResult(String bidPriceId, String supplierId){
		return bidPriceResultService.getSupplierBidPriceResult(bidPriceId, supplierId);
	}
	
	/**
	 * @Description: 保存分项报价和总报价
	 * @author mazc
	 * @param saveSubBidPriceResultVo
	 * @return 
	 */
	@PostMapping("/saveSubBidPriceResult")
	@SysLogAnnotation(detail="保存分项报价和总报价",level = 0,operationType = OperationType.INSERT)
	public boolean saveSubBidPriceResult(@RequestBody SaveSubBidPriceResultVo saveSubBidPriceResultVo) {
		if(null == saveSubBidPriceResultVo) {
			return false;
		}
		return bidPriceResultService.saveSubBidPriceResult(saveSubBidPriceResultVo.getTenderId(), saveSubBidPriceResultVo.getSupplierOpeningResultList(),
				saveSubBidPriceResultVo.getBidPriceResultList(), saveSubBidPriceResultVo.isEvaluationPrice());
	}
	
	
	
	/**
	 * @Description: 保存供应商的报价信息
	 * @author mazc
	 * @param saveSupplierBidPriceResultVo
	 * @return 
	 */
	@PostMapping("/saveSupplierBidPriceResult")
	@SysLogAnnotation(detail="补录开标结果",level = 0,operationType = OperationType.INSERT)
	public SupplierOpeningResult saveSupplierBidPriceResult(@RequestBody SaveSupplierBidPriceResultVo saveSupplierBidPriceResultVo){
		if(null == saveSupplierBidPriceResultVo) {
			return null;
		}
		String tenderId = saveSupplierBidPriceResultVo.getTenderId();
		Date bidOpeningTime = saveSupplierBidPriceResultVo.getBidOpeningTime();
		String priceBidStatus = saveSupplierBidPriceResultVo.getPriceBidStatus();
		String bidOpeningRecord =saveSupplierBidPriceResultVo.getBidOpeningRecord();
		String bidOpeningStatus = saveSupplierBidPriceResultVo.getBidOpeningStatus();
		String businessBidStatus = saveSupplierBidPriceResultVo.getBusinessBidStatus();
		String technologyBidStatus = saveSupplierBidPriceResultVo.getTechnologyBidStatus();
		List<BidPrice> newBidPriceList = saveSupplierBidPriceResultVo.getNewBidPriceList();
		List<BidPriceResult> bidPriceResultList = saveSupplierBidPriceResultVo.getBidPriceResultList();
		SupplierOpeningResult supplierOpeningResult = saveSupplierBidPriceResultVo.getSupplierOpeningResult();
			
		return bidPriceResultService.saveSupplierBidPriceResult(tenderId, supplierOpeningResult, businessBidStatus, 
				technologyBidStatus, priceBidStatus, bidOpeningStatus, bidOpeningTime, bidOpeningRecord, newBidPriceList, bidPriceResultList);
	}
	
	/**
	 * @Description: 补录开标结果
	 * @author mazc
	 * @param saveSupplierInputBidPriceResultVo
	 * @return 
	 */
	@PostMapping("/saveSupplierInputBidPriceResult")
	@SysLogAnnotation(detail="补录开标结果",level = 0,operationType = OperationType.INSERT)
	public boolean saveSupplierInputBidPriceResult(@RequestBody SaveSupplierInputBidPriceResultVo saveSupplierInputBidPriceResultVo) {
		SupplierOpeningResult supplierOpeningResult = saveSupplierInputBidPriceResultVo.getSupplierOpeningResult();
		List<BidPriceResult> bidPriceResultList = saveSupplierInputBidPriceResultVo.getBidPriceResultList();
		boolean allBidStatus =saveSupplierInputBidPriceResultVo.isAllBidStatus();
		return bidPriceResultService.saveSupplierInputBidPriceResult(saveSupplierInputBidPriceResultVo.getTenderId(), saveSupplierInputBidPriceResultVo.getProjectId(), supplierOpeningResult, bidPriceResultList, allBidStatus);
	}
	
	/**
	 * @Description: 保存供应商多轮报价
	 * @author guoyr
	 * @return 
	 */
	@PostMapping("/saveSupplierReBidPriceResult")
	@SysLogAnnotation(detail="保存供应商多轮报价",level = 0,operationType = OperationType.INSERT)
	public boolean saveSupplierReBidPriceResult(@RequestBody RequestBodyEntity<BidPriceResult> requestBodyEntity) {
		String tenderId = (String)requestBodyEntity.getParam("tenderId");
		String supplierId = (String)requestBodyEntity.getParam("supplierId");
		String roundId = (String)requestBodyEntity.getParam("roundId");
		List<BidPriceResult> bidPriceResultList = requestBodyEntity.getEntityList();
		return bidPriceResultService.saveSupplierReBidPriceResult(tenderId, supplierId,roundId, bidPriceResultList);
		
	}
	
	/**
	 * @Description: 补录评标价
	 * @author mazc
	 * @return 
	 */
	@PostMapping("/saveSupplierInputEvaluationPriceResult")
	@Deprecated 
	public boolean saveSupplierInputEvaluationPriceResult(@RequestBody SaveSupplierInputEvaluationPriceResultVo saveSupplierInputEvaluationPriceResultVo) {
		SupplierOpeningResult supplierOpeningResult = saveSupplierInputEvaluationPriceResultVo.getSupplierOpeningResult();
		List<BidPriceResult> bidPriceResultList = saveSupplierInputEvaluationPriceResultVo.getBidPriceResultList();
		return bidPriceResultService.saveSupplierInputEvaluationPriceResult(supplierOpeningResult, bidPriceResultList);
	}
	
	/**
	 * @Description: 保存汇率转换后的评标价
	 * @author mazc
	 * @return 
	 */
	@PostMapping("/saveExchangeRateEvaluation")
	@SysLogAnnotation(detail="保存汇率转换后的评标价",level = 0,operationType = OperationType.UPDATE)
	public boolean saveExchangeRateEvaluation(@RequestBody RequestBodyEntity<BidPriceResult> rRequestBodyEntity) {
 		@SuppressWarnings("unchecked")
		TenderProject tenderProjectEntity = (TenderProject) EntityUtill.toBean((Map<String, Object>)rRequestBodyEntity.getParam("tenderProjectEntity"),TenderProject.class );
		List<BidPriceResult> bidPriceResultList = rRequestBodyEntity.getEntityList();
		return bidPriceResultService.saveExchangeRateEvaluation(tenderProjectEntity, bidPriceResultList);
	}
	
	@GetMapping("/getTenderIdAndBidPrice")
	public List<BidPriceResult> getTenderIdAndBidPrice(String tenderId, String bidPrice){
		return bidPriceResultService.getTenderIdAndBidPrice(tenderId, bidPrice);
	}
	
	@GetMapping("/hasBidPriceResult")
	public boolean hasBidPriceResult(String tenderId){
		return bidPriceResultService.hasBidPriceResult(tenderId);
	}
	
	@PostMapping("/updateAssignProperty")
	public boolean updateAssignProperty(@RequestBody UpdateAssignPropertyVo<BidPriceResult> updateAssignPropertyVo){
		BidPriceResult bidPriceResult = updateAssignPropertyVo.getEntity();
		String[] attributes = updateAssignPropertyVo.getAttributes();
		return bidPriceResultService.updateAssignProperty(bidPriceResult, attributes);
	}
	
	@PostMapping("/batchSaveOrUpdate")
	public int batchSaveOrUpdate(@RequestBody List<BidPriceResult> bidPriceResultList){
		return bidPriceResultService.batchSaveOrUpdate(bidPriceResultList);
	}
	@GetMapping("/updateCurrencyCodeAndPriceUnitAndEvaluationPrice")
	public boolean updateCurrencyCodeAndPriceUnitAndEvaluationPrice(String tenderId,String bidPriceId,String supplierId,String priceUnit,String currencyCode,String bidPrice, String evaluationPrice,String evaluationPriceOriginal){
		return bidPriceResultService.updateCurrencyCodeAndPriceUnitAndEvaluationPrice(tenderId, bidPriceId, supplierId, priceUnit, currencyCode, bidPrice, evaluationPrice, evaluationPriceOriginal);
	}

	@PostMapping("/updateBidPriceResultOrSum")
	@SysLogAnnotation(detail="修正报价",level = 0,operationType = OperationType.UPDATE)
	public boolean updateBidPriceResultOrSum(@RequestBody BidPriceResult bidPriceResult){
		return bidPriceResultService.updateBidPriceResultOrSum(bidPriceResult);
	}

	@PostMapping("/updateBidPriceAndFinalPrice")
	@SysLogAnnotation(detail = "修正含税不含税", operationType = OperationType.UPDATE)
	public boolean updateBidPriceAndFinalPrice(@RequestBody Map<String, Object> bidPriceResult) {
		return bidPriceResultService.updateBidPriceAndFinalPrice(bidPriceResult);
	}
	
	/**
	 * @Description: 将未完成报价的供应商报价自动填充上一轮报价
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	@PostMapping("/updateSupplierIdNotRecordedBidPrice")
	@SysLogAnnotation(detail="将未完成报价的供应商报价自动填充上一轮报价",level = 0,operationType = OperationType.INSERT)
	public boolean updateSupplierIdNotRecordedBidPrice(String tenderId,String roundId){
		return bidPriceResultService.updateSupplierIdNotRecordedBidPrice(tenderId, roundId);
	}
}