package com.gx.obe.server.management.evaluation.controller;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.common.vo.RequestBodyEntity;
import com.gx.obe.server.management.evaluation.entity.EvaluationFactorResult;
import com.gx.obe.server.management.evaluation.service.EvaluationFactorResultService;

import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;


/**
 * @Description:
 * @author mazc
 */
@Api(tags = "")
@RestController
@AllArgsConstructor
@RequestMapping("/evaluationFactorResult")
public class EvaluationFactorResultController extends BaseController<EvaluationFactorResultService, EvaluationFactorResult> {
    
    @Autowired
    public EvaluationFactorResultService evaluationFactorResultService;
    
    /**
     * @Description: 批量插入
     * @author mazc
     * @param ObeEvaluationFactorResultList
     */
    @PostMapping("/insertByBatch")
    public int insertByBatch(@RequestBody List<EvaluationFactorResult> ObeEvaluationFactorResultList) {
        return evaluationFactorResultService.insertByBatch(ObeEvaluationFactorResultList);
    }
    
    /**
     * @Description: 批量更新
     * @author mazc
     * @param ObeEvaluationFactorResultList
     */
    @PostMapping("/updateByBatch")
    public int updateByBatch(@RequestBody List<EvaluationFactorResult> ObeEvaluationFactorResultList) {
        return evaluationFactorResultService.updateByBatch(ObeEvaluationFactorResultList);
    }
    
    /**
     * @Description: 检查项指标的结果
     * @author mazc
     * @param tenderProjectId
     * @param stepId
     * @param supplierId
     * @param factorId
     * @param userId
     * @return
     */
    @GetMapping("/checklObjectiveFactorResult")
    public List<Object> checklObjectiveFactorResult(String tenderProjectId, String stepId, String supplierId, String factorId, String userId) {
        QueryWrapper<EvaluationFactorResult> wrapper = new QueryWrapper<EvaluationFactorResult>();
        wrapper.lambda().select(EvaluationFactorResult::getEvaluationResult)
                        .eq(EvaluationFactorResult::getTenderId, tenderProjectId)
                        .eq(EvaluationFactorResult::getStepId, stepId)
                        .eq(EvaluationFactorResult::getSupplierId, supplierId)
                        .eq(EvaluationFactorResult::getFactorId, factorId)
                        .ne(EvaluationFactorResult::getUserId, userId);
        return evaluationFactorResultService.listObjs(wrapper);
    }
    
    /**
     * @Description: 获得评标结果类型
     * @author wangxiang
     * @param tenderId
     * @param stepId
     * @param supplierId
     * @param factorId
     * @param userId
     * @return
     */
    @GetMapping("/getEvaluationScoreListNotUserId")
    public List<Object> getEvaluationScoreListNotUserId(String tenderId, String stepId, String supplierId, String factorId, String userId) {
        QueryWrapper<EvaluationFactorResult> wrapper = new QueryWrapper<EvaluationFactorResult>();
        wrapper.lambda().select(EvaluationFactorResult::getEvaluationScore)
                        .eq(EvaluationFactorResult::getTenderId, tenderId)
                        .eq(EvaluationFactorResult::getStepId, stepId)
                        .eq(EvaluationFactorResult::getStepId, stepId)
                        .eq(EvaluationFactorResult::getSupplierId, supplierId)
                        .eq(EvaluationFactorResult::getFactorId, factorId)
                        .ne(EvaluationFactorResult::getUserId, userId);
        return evaluationFactorResultService.listObjs(wrapper);
    }
    
    /**
     * @Description: 评审当前评标专家所有的评标结果
     * @author mazc
     * @param tenderId
     * @param stepId
     * @param userId
     * @param supplierId
     * @return
     */
    @GetMapping("/getExpertEvaluationFactorResult")
    public List<EvaluationFactorResult> getExpertEvaluationFactorResult(String tenderId, String stepId, String userId, String supplierId) {
        return evaluationFactorResultService.getExpertEvaluationFactorResult(tenderId, stepId, userId, supplierId);
    }
    
    /**
     * @Description: 获得按供就商打分结果列表
     * @author guoyr
     * @param projectId
     * @param supplierName
     * @param groupCode
     * @return
     */
    @GetMapping("/getSupplierEvaluationFactorResult")
    public List<Map<String, Object>> getSupplierEvaluationFactorResult(String projectId, String groupCode, String userId, String supplierName) {
        return evaluationFactorResultService.getSupplierEvaluationFactorResult(projectId, groupCode, userId, supplierName);
    }
    
    /**
     * @Description: 保存按供应商打分结果
     * @author guoyr
     * @param supplierEvaluationFactorResultList
     */
    @PostMapping("/saveEvaluationResultBySupplier")
    public void saveEvaluationResultBySupplier(@RequestBody RequestBodyEntity<Map<String, Object>> requestBodyEntity) {
        String projectId = (String) requestBodyEntity.getParam("projectId");
        String groupCode = (String) requestBodyEntity.getParam("groupCode");
        String userId = (String) requestBodyEntity.getParam("userId");
        List<Map<String, Object>> supplierEvaluationFactorResultList = requestBodyEntity.getEntityList();
        evaluationFactorResultService.saveEvaluationResultBySupplier(projectId, groupCode, userId, supplierEvaluationFactorResultList);
    }
    
    /**
     * @Description: 获得指标的平均分
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @param userId
     * @return
     */
    @GetMapping("/getEvaluationFactorAvgScoreList")
    public List<Map<String, Object>> getEvaluationFactorAvgScoreList(String tenderId, String stepId, String supplierId, boolean removeMaxMin) {
        return evaluationFactorResultService.getEvaluationFactorAvgScoreList(tenderId, stepId, supplierId, removeMaxMin);
    }
    
    /**
     * @Description: 根据指标Id获取当前专家对应的指标评审结果
     * @author chenxw
     * @param factorId
     * @return
     */
    @GetMapping("/getEvaluationFactorResultList")
    public List<EvaluationFactorResult> getEvaluationFactorResultList(String tenderId, String stepId, String factorId, String userId) {
        return evaluationFactorResultService.getEvaluationFactorResultList(tenderId, stepId, factorId, userId);
    }
    
    /**
     * @Description: 获得评标专家的评标结果列表
     * @author guoyr
     * @param factorType
     */
    @GetMapping("/getResultListByFactorType")
    public List<EvaluationFactorResult> getResultListByFactorType(String tenderId, String factorType) {
        return evaluationFactorResultService.getResultListByFactorType(tenderId, factorType);
    }
    
    /**
     * @Description: 获取指定指标不同评审结果的个数
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @param factorId
     * @param userId
     * @param result
     * @param score
     * @return
     */
    @GetMapping("/getSupplierDistinctFactorCount")
    public int getSupplierDistinctFactorCount(String tenderId, String stepId, String factorId, String userId, String result, BigDecimal score) {
        return evaluationFactorResultService.getSupplierDistinctFactorCount(tenderId, stepId, factorId, userId, result, score);
    }
    
    /**
     * @Description: 获取同一指标评标结果不同的列表
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @param isScoreFactor
     * @return
     */
    @GetMapping("/getSupplierDistinctFactorResultList")
    public List<Map<String, Object>> getSupplierDistinctFactorResultList(String tenderId, String stepId, boolean isScoreFactor) {
        return evaluationFactorResultService.getSupplierDistinctFactorResultList(tenderId, stepId, isScoreFactor);
    }
    
    /**
     * @Description: 获取得分列表
     * @author chenxw
     * @param tenderId
     * @param stepId
     * @param supplierId
     * @param factorId
     * @return
     */
    @GetMapping("/getEvaluationScoreList")
    public List<Object> getEvaluationScoreList(String tenderId, String stepId, String supplierId, String factorId) {
        return evaluationFactorResultService.getEvaluationScoreList(tenderId, stepId, supplierId, factorId);
    }
    
}