package com.gx.obe.server.management.evaluation.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.management.evaluation.entity.EvaluationGroup;
import com.gx.obe.server.management.evaluation.service.EvaluationGroupService;

import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;

/**
 * @Description:
 * @author mazc
 */
@Api(tags = "")
@RestController
@AllArgsConstructor
@RequestMapping("/evaluationGroup")
public class EvaluationGroupController extends BaseController<EvaluationGroupService, EvaluationGroup> {
    
    @Autowired
    public EvaluationGroupService evaluationGroupService;
    
    /**
     * @Description: 批量插入
     * @author mazc
     * @param ObeEvaluationGroupList
     */
    @PostMapping("/insertByBatch")
    public int insertByBatch(@RequestBody List<EvaluationGroup> ObeEvaluationGroupList) {
        return evaluationGroupService.insertByBatch(ObeEvaluationGroupList);
    }
    
    /**
     * @Description: 批量更新
     * @author mazc
     * @param ObeEvaluationGroupList
     */
    @PostMapping("/updateByBatch")
    public int updateByBatch(@RequestBody List<EvaluationGroup> ObeEvaluationGroupList) {
        return evaluationGroupService.updateByBatch(ObeEvaluationGroupList);
    }
    
    /**
     * @Description: 根据用户id获取评审分组
     * @author chenxw
     * @param tenderId
     * @param userId
     * @param stepId
     * @return
     */
    @GetMapping("/getEvaluationGroupByUserId")
    private List<EvaluationGroup> getEvaluationGroupByUserId(String tenderId, String userId, String stepId) {
        return evaluationGroupService.getEvaluationGroupByUserId(tenderId, userId, stepId);
    }
    
    /**
     * @Description: 删除评审分组
     * @author wangxiang
     * @param tenderId
     */
    @GetMapping("/deleteByTenderId")
    public boolean deleteByTenderId(String tenderId) {
        QueryWrapper<EvaluationGroup> queryWrapper = new QueryWrapper<EvaluationGroup>();
        queryWrapper.lambda().eq(EvaluationGroup::getTenderId, tenderId);
        return evaluationGroupService.remove(queryWrapper);
    }
    
    /**
     * @Description: 删除条件为tenderid StepId
     * @author mazc
     * @param tenderId
     * @param stepId
     * @return
     */
    @GetMapping("/deleteByTenderIdAndStepId")
    public int deleteByTenderIdAndStepId(String tenderId, String stepId) {
        return evaluationGroupService.deleteByTenderIdAndStepId(tenderId, stepId);
    }
    
}