package com.gx.obe.server.management.evaluation.service;

import java.math.BigDecimal;
import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.gx.obe.server.management.boq.entity.ObeSupplyMaterialDetail;
import com.gx.obe.server.management.evaluation.entity.EvaluationFactor;
import com.gx.obe.server.management.evaluation.entity.EvaluationStep;
import com.gx.obe.server.management.project.entity.TenderProject;

/**
 * 
 * @author 
 * @Title: EvaluationFactorService
 * @Package com.gx.obe.server.management.evaluation.service  
 * @Description:    
 * @author: XiaoMa Pro - myzhichao@163.com
 * @date:   2019-05-17   
 * @version V1.0 
 * @Copyright: 2019 www.msypro.com Inc. All rights reserved. 
 *  
 */
public interface EvaluationFactorService extends IService<EvaluationFactor> {
	
	public List<EvaluationFactor> selectBatchIds(List<String> lsit);
	
	/**
     * @Description: 保存或修改符合性评审指标
     * @author guoyr
     * @param factor
     * @return
     */
    public EvaluationFactor saveOrUpdateComplianceEvaluationFactor(EvaluationFactor factor);
    
    /**
     * @Description: 保存或修改打分评审指标
     * @author guoyr
     * @param factor
     * @param changeWeigth 是否修改权重
     * @return
     */
    public EvaluationFactor saveEvaluationFactor(EvaluationFactor factor, boolean changeWeigth);
    
    /**
     * @Description: 删除指标
     * @author guoyr
     * @param factor
     * @return
     */
    public int deleteEvaluationFactor(EvaluationFactor factor);
    
    /**
     * @Description: 获得价格指标
     * @author guoyr
     * @param tenderId
     * @return
     */
    public EvaluationFactor getPriceEvaluationFactor(String tenderId);

    /**
     * @Description: 交换两个指标的排序
     * @author guoyr
     * @param source
     * @param target
     */
    public void changeEvaluationFactorSortNo(String sourceId, String targetId);
    
    /**
     * @Description: 获得指标的最大序号
     * @author guoyr
     * @param parentId
     * @return
     */
    public int getMaxEvaluationFactorSortNo(String tenderId, String auditType, String parentId);
    
    /**
     * @Description: 获得指标的数量
     * @author guoyr
     * @return
     */
    public int getEvaluationFactorCount(String tenderId, String auditType);
    
    /**
     * @Description:  获得全部的指标
     * @author guoyr
     * @param auditType
     * @return
     */
    public List<EvaluationFactor> getAllEvaluationFactorList(String tenderId, String auditType);
    
    /**
     * @Description: 导入投标报价指标
     * @author guoyr
     * @param tenderId 
     */
    public int importBidPriceFactor(String tenderId, EvaluationFactor parentFactor);
    
    /**
     * @Description: 导入指标
     * @author guoyr
     * @param tenderId
     * @param complianceFactorList 符合性指标
     * @param detailFactorList 打分指标
     * @param priceFactorList 价格指标
     * @return
     */
    public boolean importEvaluationFactor(String tenderId, List<EvaluationFactor> complianceFactorList, List<EvaluationFactor> detailFactorList, List<EvaluationFactor> priceFactorList, List<EvaluationFactor> billFactorList);
    
    /**
     * @Description: 删除所有指标
     * @author guoyr
     * @param tenderId
     */
    public void delAllEvaluationFactor(String tenderId);
    
    /**
     * @Description: 按分类删除指标
     * @author guoyr
     * @param tenderId
     * @param auditType
     * @return 
     */
    public int delEvaluationFactorByType(String tenderId, String auditType);
    
    /**
     * @Description: 获得可为评标步骤分配置的指标
     * @author guoyr
     * @param tenderId
     * @param auditType
     * @return
     */
    public List<EvaluationFactor> getFactorListOfEvaluationStep(String tenderId, String auditType, String stepId);
    
    /**
     * @Description: 获得指定评标步骤的评审指标树
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @return
     */
    public List<EvaluationFactor> getEvaluationStepFactorTreeList(String tenderId, EvaluationStep evaluationStep);
    
    /**
     * @Description: 获得专家在指定评标步骤的评审指标树
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @param userId
     * @return
     */
    public List<EvaluationFactor> getExpertEvaluationStepFactorTreeList(String tenderId, EvaluationStep evaluationStep, String userId);
    
    /**
     * @Description: 获取项目下指定类型的指标的主键
     * @author guoyr
     * @param tenderId
     * @param auditType
     * @return
     */
    public List<Object> getFactorIdList(String tenderId, String auditType);

    /**
     * @Description: 保存下载的评审指标
     * @author guoyr
     * @param tenderId
     * @param evaluationFactorList
     * @return
     */
    public int saveDownloadEvaluationFactor(String tenderId, List<EvaluationFactor> evaluationFactorList);

    /** 
     * @Description: 获得指定评标步骤的评审指标(未对指标信息封装树节点，现在主要用于生成报表使用)
     * @author guoyr
     * @param tenderId
     * @param evaluationStep
     * @param removeTopOnly 当顶级指标只有一个时，取掉顶级指标
     * @return 
     */
    public List<EvaluationFactor> getEvaluationStepFactorList(String tenderId, EvaluationStep evaluationStep, boolean removeTopOnly);
    
    /** 
     * @Description: 获得专家在指定评标步骤的评审指标(未对指标信息封装树节点，现在主要用于生成报表使用)
     * @author guoyr
     * @param tenderId
     * @param evaluationStep
     * @param removeTopOnly 当顶级指标只有一个时，取掉顶级指标
     * @return 
     */
    public List<EvaluationFactor> getExpertEvaluationStepFactorList(String tenderId, EvaluationStep evaluationStep, String userId, boolean removeTopOnly);
    
    /**
     * @Description: 获得父级评审指标分值
     * @param tenderId
     * @param stepId
     * @return
     */
    public BigDecimal getParentFactorScore(String tenderId, String stepId);
    
    /**
     * @Description: 获得指定专家对投标人的评标结果
     * @author guoyr
     * @param tenderId
     * @param userId
     * @param supplierId
     * @param stepId
     * @param auditType
     * @return
     */
    public List<EvaluationFactor> getEvaluationFactorResultList(String tenderId, String userId, String supplierId, String stepId, String auditType);
    
    /**
     * @Description: 验证是否已经存在投标总报价价格指标
     * @author guoyr
     * @param tenderId
     * @param factorId
     * @return 
     */
    public boolean hasTotalBidPriceFactor(String tenderId, String factorId);
    
    /**
     * @Description: 获得指定指标类形的权重
     * @author guoyr
     * @param tenderId
     * @param auditType
     * @return 
     */
    public BigDecimal getWeightByAuditType(String tenderId, String auditType);
    
    /**
     * @Description: 根据清单类型获取清单指标
     * @author chenxw
     * @param tenderId
     * @param billType
     * @return 
     */
    public EvaluationFactor getBillFactoryByType(String tenderId, String billType);

    /**
     * @Description: 根据步骤id获取权重
     * @author chenxw
     * @param tenderId
     * @param id
     * @return 
     */
    public BigDecimal getWeightByStepId(String tenderId, String stepId);

    /**
     * @Description: 根据步骤id获取得分
     * @author chenxw
     * @param tenderId
     * @param stepId
     * @param weightScore 
     * @return 
     */
    public BigDecimal getScoreByStepId(String tenderId, String stepId, boolean weightScore);

    /**
     * @Description: 获得指定指标类形的得分
     * @author chenxw
     * @param tenderId
     * @param auditType
     * @param weightScore
     * @return 
     */
    public BigDecimal getScoreByAuditType(String tenderId, String auditType, boolean weightScore);

    /**
     * @Description: 根据项目id获取指标数量
     * @author chenxw
     * @param tenderId
     * @return 
     */
    public int getFactorCountByTenderId(String tenderId);

    /**
     * @Description: 根据项目id获取指标列表
     * @author chenxw
     * @param tenderId
     * @return 
     */
    public List<EvaluationFactor> getFactorListByTenderId(String tenderId);
    
    /**
     * @Description: 根据指标编号获取指标
     * @author chenxw
     * @param tenderId
     * @param factorCode
     * @return 
     */
    public EvaluationFactor getFactorByFactorCode(String tenderId, String factorCode);

     /**
      * @Description: 保存商务指标
      * @author chenxw
      * @param tenderProject
      * @param businessFactor
      * @return
      */
     boolean saveBusinessFactor(TenderProject tenderProject, EvaluationFactor businessFactor);
 
     boolean updateAssignProperty(EvaluationFactor evaluationStep, String[] attributes);
     
     Integer batchUpdateProperty(List<EvaluationFactor> evaluationStep, String[] attributes);
}

