package com.gx.obe.server.management.evaluation.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.enumeration.BidPriceEnum;
import com.gx.obe.server.common.enumeration.CommonEnum;
import com.gx.obe.server.common.enumeration.SupplierEnum;
import com.gx.obe.server.common.utils.BigDecimalUtils;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.NowTimeUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.evaluation.dao.BidPriceHisResultMapper;
import com.gx.obe.server.management.evaluation.dao.BidPriceItemMapper;
import com.gx.obe.server.management.evaluation.dao.BidPriceItemResultMapper;
import com.gx.obe.server.management.evaluation.dao.BidPriceMapper;
import com.gx.obe.server.management.evaluation.dao.BidPriceResultMapper;
import com.gx.obe.server.management.evaluation.entity.BidPrice;
import com.gx.obe.server.management.evaluation.entity.BidPriceHisResult;
import com.gx.obe.server.management.evaluation.entity.BidPriceResult;
import com.gx.obe.server.management.evaluation.service.BidPriceHisResultService;
import com.gx.obe.server.management.evaluation.service.BidPriceItemResultService;
import com.gx.obe.server.management.evaluation.service.BidPriceResultService;
import com.gx.obe.server.management.price.dao.BidPriceRoundStatusMapper;
import com.gx.obe.server.management.price.dao.ReBidPriceRoundMapper;
import com.gx.obe.server.management.price.entity.ReBidPriceRound;
import com.gx.obe.server.management.price.service.BidPriceRoundStatusService;
import com.gx.obe.server.management.price.service.ReBidPriceRoundService;
import com.gx.obe.server.management.project.dao.ProjectRuleMapper;
import com.gx.obe.server.management.project.dao.TenderProjectMapper;
import com.gx.obe.server.management.project.entity.TenderProject;
import com.gx.obe.server.management.supplier.dao.SupplierMapper;
import com.gx.obe.server.management.supplier.dao.SupplierOpeningResultMapper;
import com.gx.obe.server.management.supplier.entity.SupplierOpeningResult;
import com.gx.obe.server.management.supplier.service.SupplierOpeningResultService;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
@Transactional
public class BidPriceResultServiceImpl extends ServiceImpl<BidPriceResultMapper, BidPriceResult> implements BidPriceResultService {
	
	private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(BidPriceResultServiceImpl.class);
	
	@Autowired
	private BidPriceResultMapper bidPriceResultMapper;
	
	@Autowired
	private BidPriceHisResultMapper bidPriceHisResultMapper;
	
	@Autowired
	private  BidPriceItemResultService bidPriceItemResultService;

	@Autowired
	private SupplierOpeningResultMapper supplierOpeningResultMapper;
	
	@Autowired
	private SupplierOpeningResultService supplierOpeningResultService;
	
	@Autowired
	private BidPriceItemMapper bidPriceItemMapper;
	
	@Autowired
	private TenderProjectMapper tenderProjectMapper;

	@Autowired
	private ProjectRuleMapper projectRuleMapper;
	
	@Autowired
	private BidPriceMapper bidPriceMapper;
	
	@Autowired
	private BidPriceItemResultMapper bidPriceItemResultMapper;
	
	@Autowired
	private SupplierMapper supplierMapper;
	
	@Autowired
	private BidPriceHisResultService bidPriceHisResultService;

	@Autowired
	private BidPriceRoundStatusMapper bidPriceRoundStatusMapper;
	
	@Autowired
	private BidPriceRoundStatusService bidPriceRoundStatusService;
	
	@Autowired
	private ReBidPriceRoundMapper reBidPriceRoundMapper;
	
	@Autowired
	private ReBidPriceRoundService reBidPriceRoundService;
	/** 
	 * @Description: 获得供应商开标一览表
	 * @author guoyr
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	@Override
	public List<BidPriceResult> getBidPriceResultTableList(String tenderId, String supplierId) {
		return bidPriceResultMapper.getBidPriceResultTableList(tenderId, supplierId);
	}
	@Override
	public List<BidPriceResult> findBidPriceResultList(String tenderId, String bidPriceId) {
		return bidPriceResultMapper.findBidPriceResultList(tenderId, bidPriceId);
	}

	/**
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param ObeBidPriceResult
	 * @param attributes
	 */
	@Override
	public boolean updateAssignProperty(BidPriceResult ObeBidPriceResult, String[] attributes) {
		return bidPriceResultMapper.updateAssignProperty(ObeBidPriceResult, attributes) > 0;
	}

	/**
	 * @Description: 批量指定字段修改
	 * @author chenxw
	 * @param ObeBidPriceResultList
	 * @param attributes
	 */
	@Override
	public Integer batchUpdateProperty(List<BidPriceResult> ObeBidPriceResultList, String[] attributes) {
		return bidPriceResultMapper.batchUpdateProperty(ObeBidPriceResultList, attributes);
	}

	/**
	 * @Description: 批量添加或跟新
	 * @author chenxw
	 * @param bidPriceResultList
	 * @param attributes
	 * @return
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer batchSaveOrUpdate(List<BidPriceResult> bidPriceResultList, String[] attributes) {
		List<BidPriceResult> insertObeBidPriceResultList = new ArrayList<>();
		List<BidPriceResult> updateObeBidPriceResultList = new ArrayList<>();
		for (BidPriceResult ObeBidPriceResult : bidPriceResultList) {
			if (StringUtils.isEmpty(ObeBidPriceResult.getId())) {
				ObeBidPriceResult.setId(IDUtils.getId());
				insertObeBidPriceResultList.add(ObeBidPriceResult);
			} else {
				updateObeBidPriceResultList.add(ObeBidPriceResult);
			}
		}
		int count = 0;
		if (insertObeBidPriceResultList.size() > 0) {
			count += bidPriceResultMapper.insertByBatch(insertObeBidPriceResultList);
		}
		if (updateObeBidPriceResultList.size() > 0) {
			if(null != attributes && attributes.length > 0) {
				count += bidPriceResultMapper.batchUpdateProperty(updateObeBidPriceResultList, attributes);
			}else {
				count += bidPriceResultMapper.updateObeBidPriceResultBatchList(updateObeBidPriceResultList);
			}
		}
		return count;
	}
	

	/** 
	 * @Description: 获得分项报价结果
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	@Override
	public List<BidPriceResult> getBidPriceResultList(String tenderId) {
		QueryWrapper<BidPriceResult> queryWrapper = new QueryWrapper<BidPriceResult>();
		queryWrapper.eq(BidPriceResult.TENDER_ID, tenderId);
		return bidPriceResultMapper.selectList(queryWrapper);
	}

	@Override
	public List<BidPriceResult> getSingBidPriceResultList(String tenderId) {
		return bidPriceResultMapper.getSingBidPriceResultList(tenderId);
	}

	@Override
	public List<BidPriceResult> getSupplierBidPriceResultList(String tenderId, String supplierId) {
		return bidPriceResultMapper.getSupplierBidPriceResultList(tenderId, supplierId);
	}

	/** 
	 * @Description: 获得供应商的分项报价 
	 * @author mazc
	 * @param bidPriceId
	 * @param supplierId
	 * @return 
	 */
	@Override
	public BidPriceResult getSupplierBidPriceResult(String bidPriceId, String supplierId) {
		return bidPriceResultMapper.getSupplierBidPriceResult(bidPriceId, supplierId);
	}

	/** 
	 * @Description: 保存分项报价和总报价
	 * @author mazc
	 * @param tenderId
	 * @param supplierOpeningResultList
	 * @param bidPriceResultList
	 * @param isEvaluationPrice
	 * @return 
	 */
	@Override
	@Transactional(noRollbackFor = Exception.class)
	public boolean saveSubBidPriceResult(String tenderId, List<SupplierOpeningResult> supplierOpeningResultList,
			List<BidPriceResult> bidPriceResultList, boolean isEvaluationPrice) {
		if(null != supplierOpeningResultList){
			for(SupplierOpeningResult supplierOpeningResult : supplierOpeningResultList){
				if(null == supplierOpeningResult.getId()){
					supplierOpeningResult.setId(supplierOpeningResultMapper.getSupplierOpeningResultId(supplierOpeningResult.getTenderId(), supplierOpeningResult.getSupplierId()));
				}
			}
			if(isEvaluationPrice){
				supplierOpeningResultService.batchSaveOrUpdate(supplierOpeningResultList, new String[]{"id","bidPrice", "finalBidPrice", "evaluationPrice", "revokeStatus", "modifyReason"});
			}else {
				supplierOpeningResultService.batchSaveOrUpdate(supplierOpeningResultList, new String[]{"id","bidPrice", "finalBidPrice", "evaluationPrice", "bidOpeningStatus", "priceBidStatus", "businessBidStatus", "technologyBidStatus", "bidOpeningTime", "revokeStatus"});
			}
		}
		int size = batchSaveOrUpdate(bidPriceResultList, new String[]{"id","bidPrice", "finalBidPrice", "evaluationPriceOriginal", "evaluationPrice","modifyReason"});
		
		return size > 0;
	}

	@Override
	public SupplierOpeningResult saveSupplierBidPriceResult(String tenderId,
			SupplierOpeningResult supplierOpeningResult, String businessBidStatus, String technologyBidStatus,
			String priceBidStatus, String bidOpeningStatus, Date bidOpeningTime, String bidOpeningRecord,
			List<BidPrice> newBidPriceList, List<BidPriceResult> bidPriceResultList) {
		
			String bidBondType = null;
			boolean decPriceBid = (null != priceBidStatus && priceBidStatus.length() > 0) ? true : false;
			List<String> assignUpdateProperty = new ArrayList<String>();
			assignUpdateProperty.add("id");
			
			if(null != businessBidStatus && businessBidStatus.length() > 0){
				supplierOpeningResult.setBusinessBidStatus(businessBidStatus);
				assignUpdateProperty.add("businessBidStatus");
				if(null != bidOpeningTime){
					supplierOpeningResult.setBidOpeningTime(bidOpeningTime);
					assignUpdateProperty.add("bidOpeningTime");
				}
			}
			
			if(null != technologyBidStatus && technologyBidStatus.length() > 0){
				supplierOpeningResult.setTechnologyBidStatus(technologyBidStatus);
				assignUpdateProperty.add("technologyBidStatus");
				if(null != bidOpeningTime && null == supplierOpeningResult.getBidOpeningTime()){
					supplierOpeningResult.setBidOpeningTime(bidOpeningTime);
					assignUpdateProperty.add("bidOpeningTime");
				}
			}
			if(null != priceBidStatus && priceBidStatus.length() > 0){
				supplierOpeningResult.setPriceBidStatus(priceBidStatus);
				assignUpdateProperty.add("priceBidStatus");
				if(null != bidOpeningTime){
					supplierOpeningResult.setPriceBidOpeningTime(bidOpeningTime);
					assignUpdateProperty.add("priceBidOpeningTime");
				}
			}
			supplierOpeningResult.setRevokeStatus(SupplierEnum.REVOKE_NO);
			assignUpdateProperty.add("revokeStatus");
			
			if(null == supplierOpeningResult.getId()){
				LOG.error(tenderId + "所对应开标结果无主键-------------" + (new Date()));
				String supplierOpeningResultId = supplierOpeningResultMapper.getSupplierOpeningResultId(tenderId, supplierOpeningResult.getSupplierId());
				supplierOpeningResult.setId(supplierOpeningResultId);
			}

			
			if(null == supplierOpeningResult.getBidOpeningStatus() || !supplierOpeningResult.getBidOpeningStatus().equals(SupplierEnum.OPENBID_SUCCESS)){
				supplierOpeningResult.setBidOpeningStatus(bidOpeningStatus);
				assignUpdateProperty.add("bidOpeningStatus");
			}
			
			if(null != bidOpeningRecord && bidOpeningRecord.length() > 0){
				supplierOpeningResult.setBidOpeningRecord(bidOpeningRecord);
				assignUpdateProperty.add("bidOpeningRecord");
			}
			// 如果进行了价格标解密
			if(decPriceBid){
				// 将一览表中的报价进行汇总，并存入供应商结果表
				BigDecimal bidPriceTotal = null;
				if(null != bidPriceResultList && bidPriceResultList.size() > 0){
					
					BidPriceResult firstBidPriceResult = bidPriceResultList.get(0);
					supplierOpeningResult.setCurrencyCode(firstBidPriceResult.getCurrencyCode());
 					supplierOpeningResult.setPriceUnit(firstBidPriceResult.getPriceUnit());
					assignUpdateProperty.add("currencyCode");
 					assignUpdateProperty.add("priceUnit");
 					
					List<BidPriceResult> bidPriceItemList = new ArrayList<BidPriceResult>();
					Date nowTime = NowTimeUtils.getNowDate();
					int joinTotalCount = 0;
					for(BidPriceResult bidPriceResult : bidPriceResultList){
						if(null == bidPriceResult.getFinalBidPrice()) {
							bidPriceResult.setFinalBidPrice(bidPriceResult.getBidPrice());
						}
						bidPriceResult.setEvaluationPrice(bidPriceResult.getBidPrice());
						bidPriceResult.setCreateTime(nowTime);
						if(BidPriceEnum.IS_PRICE_ITEM.equals(bidPriceResult.getBidPriceType())){
							
							if(BidPriceEnum.JOIN_TOTAL.equals(bidPriceResult.getJoinTotal())){
								joinTotalCount ++;
								if(null != bidPriceResult.getBidPrice()) {
									bidPriceTotal = BigDecimalUtils.add(bidPriceTotal, bidPriceResult.getBidPrice());
								}
							}
							bidPriceItemList.add(bidPriceResult);
							if(joinTotalCount == 1) {
								if(projectRuleMapper.canMofifyPriceUnitFormSupplierBidPrice(tenderId, bidPriceResult.getCurrencyCode()) > 0) {
									// 币种及单位，判断一下如果没有项目上的评标金额设置才进行修改
									projectRuleMapper.updatePriceUnitFromSupplierBidPrice(tenderId, bidPriceResult.getPriceUnit());
								}
							}
						}
						

						// TODO 大唐提要求投标保证金通过在开标一览表中自动识别：如果开标览表中存放的是“是”或“有”，则记录投标保证金状态为01
						if(BidPriceEnum.ITEM_CODE_BID_DEPOSIT.equals(bidPriceResult.getBidPriceCode())){
							bidBondType = "00";
							if(null != bidPriceResult.getBidPrice() && bidPriceResult.getBidPrice().compareTo(BigDecimal.ZERO) > 0) {
								bidBondType = "01";
							}else {
								String itemValue = null != bidPriceResult.getPriceContent() ? bidPriceResult.getPriceContent().trim() : "";
								if("有".equals(itemValue) || "是".equals(itemValue)){
									bidBondType = "01";
								}
							}
						}
						if(null == bidPriceResult.getId()) {
							bidPriceResult.setId(IDUtils.getId());
						}
					}
					if(joinTotalCount == 0) {
						for(BidPriceResult bidPriceResult : bidPriceResultList){
							if(BidPriceEnum.IS_PRICE_ITEM.equals(bidPriceResult.getBidPriceType())){
								// 如果有多个报价项，但是没有一个是计入总价的，则默认将第一个计入总价
								bidPriceTotal = BigDecimalUtils.add(bidPriceTotal, bidPriceResult.getBidPrice());
								bidPriceMapper.updateBidPriceType(bidPriceResult.getBidPriceId(),  bidPriceResult.getBidPriceType(),  BidPriceEnum.JOIN_TOTAL,  bidPriceResult.getPriceType());
								if(projectRuleMapper.canMofifyPriceUnitFormSupplierBidPrice(tenderId, bidPriceResult.getCurrencyCode()) > 0) {
									// 币种及单位，判断一下如果没有项目上的评标金额设置才进行修改
									projectRuleMapper.updatePriceUnitFromSupplierBidPrice(tenderId, bidPriceResult.getPriceUnit());
								}
								break;
							}
						}
						
						
					}
				}
				supplierOpeningResult.setBidPrice(bidPriceTotal);
				supplierOpeningResult.setEvaluationPrice(bidPriceTotal);
				supplierOpeningResult.setFinalBidPrice(bidPriceTotal);
				assignUpdateProperty.add("finalBidPrice");
				assignUpdateProperty.add("bidPrice");
				assignUpdateProperty.add("evaluationPrice");
				 
				if(null != newBidPriceList && newBidPriceList.size() > 0){
					bidPriceMapper.insertByBatch(newBidPriceList);
				}
				batchSaveSupplierBidPriceResult(tenderId, supplierOpeningResult.getSupplierId(), bidPriceResultList);
			}
			if(null != supplierOpeningResult && null != supplierOpeningResult.getId()){
				supplierOpeningResultService.updateAssignProperty(supplierOpeningResult, assignUpdateProperty.toArray(new String[assignUpdateProperty.size()]));
			}
		
			if(null != bidBondType){
				supplierMapper.updateSupplierBidBondType(supplierOpeningResult.getSupplierId(), bidBondType);
			}

		return supplierOpeningResult;
	}
	
	
	@Override
	@Transactional(rollbackFor = Exception.class)
	public void batchSaveSupplierBidPriceResult(String tenderId, String supplierId,List<BidPriceResult> bidPriceResultList) {
		bidPriceResultMapper.deletePriceResult(tenderId, supplierId);
		bidPriceItemResultMapper.deletePriceResult(tenderId, supplierId);
		if(null != bidPriceResultList && bidPriceResultList.size() > 0){
			bidPriceResultMapper.insertByBatch(bidPriceResultList);
		}
	}

	
	
	/**
	 * @Description: 保存供应商补录的开标结果
	 * @author guoyr
	 * @param tenderId
	 * @param projectId
	 * @param supplierOpeningResult
	 * @param bidPriceResultList
	 * @param allBidStatus
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean saveSupplierInputBidPriceResult(String tenderId, String projectId, SupplierOpeningResult supplierOpeningResult, List<BidPriceResult> bidPriceResultList, boolean allBidStatus) {
		BigDecimal bidPriceSum = null;
		Date openingTime = NowTimeUtils.getNowDate();
		if(null != bidPriceResultList && bidPriceResultList.size() > 0){
			for(BidPriceResult bidPriceResult : bidPriceResultList){
				bidPriceResult.setFinalBidPrice(bidPriceResult.getBidPrice());
				bidPriceResult.setEvaluationPrice(bidPriceResult.getBidPrice());
				bidPriceResult.setEvaluationPriceOriginal(null);
				if(null == bidPriceResult.getCreateTime()) {
					bidPriceResult.setCreateTime(openingTime);
				}
				if(BidPriceEnum.IS_PRICE_ITEM.equals(bidPriceResult.getBidPriceType())){
					if(BidPriceEnum.JOIN_TOTAL.equals(bidPriceResult.getJoinTotal())){
						bidPriceSum = BigDecimalUtils.add(bidPriceSum, bidPriceResult.getBidPrice());
					}
				}
			}
			supplierOpeningResult.setFinalBidPrice(bidPriceSum);
			batchSaveOrUpdate(bidPriceResultList,new String[]{"id","currencyName","currencyCode","priceUnit" ,"bidPrice", "finalBidPrice", "evaluationPrice","createTime","priceContent"});
			
			supplierOpeningResult.setBidPrice(bidPriceSum);
			supplierOpeningResult.setEvaluationPrice(bidPriceSum);
		
			if(null == supplierOpeningResult.getId()){
				supplierOpeningResult.setId(supplierOpeningResultMapper.getSupplierOpeningResultId(supplierOpeningResult.getTenderId(), supplierOpeningResult.getSupplierId()));
			}
			supplierOpeningResult.setBidOpeningStatus(SupplierEnum.OPENBID_SUCCESS);
			supplierOpeningResult.setPriceBidStatus(SupplierEnum.OPENBID_SUCCESS);
			supplierOpeningResult.setRevokeStatus(SupplierEnum.REVOKE_NO);
			if(null == supplierOpeningResult.getBidOpeningTime()){
				supplierOpeningResult.setBidOpeningTime(openingTime);
			}
			if(null == supplierOpeningResult.getPriceBidOpeningTime()){
				supplierOpeningResult.setPriceBidOpeningTime(openingTime);
			}
			String[] params = null;
			if(allBidStatus){
				params = new String[]{"id","bidPrice", "evaluationPrice", "bidOpeningStatus", "businessBidStatus", "technologyBidStatus", "priceBidStatus", "bidOpeningTime", "priceBidOpeningTime", "revokeStatus", "currencyCode", "currencyName", "priceUnit","finalBidPrice"};
				supplierOpeningResult.setTechnologyBidStatus(SupplierEnum.OPENBID_SUCCESS);
				supplierOpeningResult.setBusinessBidStatus(SupplierEnum.OPENBID_SUCCESS);
			}else {
				params = new String[]{"id", "bidPrice", "evaluationPrice", "bidOpeningStatus", "priceBidStatus", "bidOpeningTime", "priceBidOpeningTime", "revokeStatus", "currencyCode", "currencyName", "priceUnit"};
			}
			
			if(null != supplierOpeningResult.getId()){
				supplierOpeningResultService.updateAssignProperty(supplierOpeningResult, params);
			}else {
				supplierOpeningResult.setId(IDUtils.getId());
				supplierOpeningResultService.saveOrUpdate(supplierOpeningResult);
			}
			
			TenderProject tenderProject = new TenderProject();
			tenderProject.setId(tenderId);
			tenderProject.setBidOpeningStatus(CommonEnum.COMPLETE);
			String[] status = null;
			if(allBidStatus){
				//设置供应商开标状体
				tenderProject.setBusinessBidStatus(CommonEnum.COMPLETE);
				tenderProject.setTechnologyBidStatus(CommonEnum.COMPLETE);
				status = new String[]{"bidOpeningStatus", "businessBidStatus", "technologyBidStatus", "priceBidStatus"};
			}else {
				status = new String[]{"bidOpeningStatus", "priceBidStatus"};
			}
			tenderProject.setPriceBidStatus(CommonEnum.COMPLETE);
			
			tenderProjectMapper.updateAssignProperty(tenderProject, status);
			// 修改父级项目状态
			tenderProjectMapper.updateBidopeningStatus(tenderId, projectId, CommonEnum.COMPLETE);
			
			
			return true;
		}
		return false;
	}
	
	/**
	 * @Description: 保存供应商多轮报价
	 * @author guoyr
	 * @param tenderId
	 * @param supplierId
	 * @param bidPriceResultList
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean saveSupplierReBidPriceResult(String tenderId, String supplierId,String roundId,List<BidPriceResult> bidPriceResultList) {
		Date openingTime = NowTimeUtils.getNowDate();
		if(null != bidPriceResultList && bidPriceResultList.size() > 0){
			for(BidPriceResult bidPriceResult : bidPriceResultList){
				bidPriceResult.setEvaluationPriceOriginal(null);
				if(null == bidPriceResult.getCreateTime()) {
					bidPriceResult.setCreateTime(openingTime);
				}
			}
			QueryWrapper<BidPriceResult> queryWrapper = new QueryWrapper<BidPriceResult>();
			queryWrapper.lambda().eq(BidPriceResult::getTenderId, tenderId);
			queryWrapper.lambda().eq(BidPriceResult::getSupplierId, supplierId);
			bidPriceResultMapper.delete(queryWrapper);
//			batchSaveOrUpdate(bidPriceResultList,new String[]{"id","currencyCode","currencyName", "priceUnit" ,"bidPrice","evaluationPrice"});
			bidPriceResultMapper.insertByBatch(bidPriceResultList);
			if(StringUtils.isNotEmpty(roundId)) {
				bidPriceRoundStatusMapper.updateCompletePriceStatusBySupplierId(roundId, supplierId,BidPriceEnum.PRICE_STATUS_OK) ;
			}
			
			supplierOpeningResultService.updateSupplierSumPrice(tenderId, supplierId, true, true);
			return true;
		}
		return false;
	}

	
	
	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean saveSupplierInputEvaluationPriceResult(SupplierOpeningResult supplierOpeningResult,
			List<BidPriceResult> bidPriceResultList) {
		BigDecimal evaluationPriceSum = null;
		if(null != bidPriceResultList && bidPriceResultList.size() > 0){
			for(BidPriceResult bidPriceResult : bidPriceResultList){
				if(null == bidPriceResult.getEvaluationPrice()){
					bidPriceResult.setEvaluationPrice(bidPriceResult.getBidPrice());
				}
				if(null != bidPriceResult.getJoinTotal() && bidPriceResult.getJoinTotal().equals(BidPriceEnum.JOIN_TOTAL)){
					evaluationPriceSum = BigDecimalUtils.add(evaluationPriceSum, bidPriceResult.getEvaluationPrice());
				}
			}
			batchSaveOrUpdate(bidPriceResultList, new String[]{"id","evaluationPrice"});
			supplierOpeningResult.setEvaluationPrice(evaluationPriceSum);
		}
		if(null == supplierOpeningResult.getId()){
			supplierOpeningResult.setId(supplierOpeningResultMapper.getSupplierOpeningResultId(supplierOpeningResult.getTenderId(), supplierOpeningResult.getSupplierId()));
		}
		if(null != supplierOpeningResult.getId()){
			supplierOpeningResultService.updateAssignProperty(supplierOpeningResult, new String[]{"evaluationPrice"});
		}else {
			supplierOpeningResultService.saveOrUpdate(supplierOpeningResult);
		}
		return true;
 	}

	@Override
	public boolean saveExchangeRateEvaluation(TenderProject tenderProjectEntity,List<BidPriceResult> bidPriceResultList) {
		boolean saveFlag = false;
		if(batchUpdateProperty(bidPriceResultList, new String[] {"id","evaluationPrice", "evaluationPriceOriginal"}) > 0){
			supplierOpeningResultService.updateSupplierSumPrice(tenderProjectEntity.getId(), false, true);
			saveFlag = true;
		}
		return saveFlag;
 	}

	@Override
	public List<BidPriceResult> getTenderIdAndBidPrice(String tenderId, String bidPrice) {
		QueryWrapper<BidPriceResult> queryWrapper = new QueryWrapper<BidPriceResult>();
		queryWrapper.lambda().eq(BidPriceResult::getTenderId, tenderId).eq(BidPriceResult::getBidPrice, bidPrice);
		return bidPriceResultMapper.selectList(queryWrapper);
	}

	@Override
	public boolean hasBidPriceResult(String tenderId) {
		QueryWrapper<BidPriceResult> queryWrapper = new QueryWrapper<BidPriceResult>();
		queryWrapper.lambda().select(BidPriceResult::getId).eq(BidPriceResult::getTenderId, tenderId);
		return bidPriceResultMapper.selectObjs(queryWrapper).size() > 0;
	}

	@Override
	public Integer batchSaveOrUpdate(List<BidPriceResult> bidPriceResultList) {
		int iCount = 0;
		List<BidPriceResult> insertBidPriceResult = new ArrayList<BidPriceResult>();
		List<BidPriceResult> UpdateBidPriceResult = new ArrayList<BidPriceResult>();
		for(BidPriceResult bidPriceResult : bidPriceResultList) {
			if(null == bidPriceResult.getId()) {
				bidPriceResult.setId(IDUtils.getId());
				insertBidPriceResult.add(bidPriceResult);
			}else {
				UpdateBidPriceResult.add(bidPriceResult);
			}
		}
		iCount += bidPriceResultMapper.updateObeBidPriceResultBatchList(UpdateBidPriceResult);
		iCount += bidPriceResultMapper.insertByBatch(insertBidPriceResult);
		return iCount;	
 	}

	@Override
	public boolean updateCurrencyCodeAndPriceUnitAndEvaluationPrice(String tenderId, String bidPriceId,
			String supplierId, String priceUnit, String currencyCode, String bidPrice, String evaluationPrice,
			String evaluationPriceOriginal) {
		UpdateWrapper<BidPriceResult> update = new UpdateWrapper<BidPriceResult>();
		update.lambda()
		.set(BidPriceResult::getPriceUnit, priceUnit)
		.set(BidPriceResult::getCurrencyCode, currencyCode)
		.set(BidPriceResult::getBidPrice, bidPrice)
		.set(BidPriceResult::getEvaluationPrice, evaluationPrice)
		.set(BidPriceResult::getEvaluationPriceOriginal, evaluationPriceOriginal)
		
		.eq(BidPriceResult::getTenderId, tenderId)
		.eq(BidPriceResult::getBidPriceId, bidPriceId)
		.eq(BidPriceResult::getSupplierId, supplierId);
		
		return bidPriceResultMapper.update(null, update) > 0;
	}

	/**
	 * @Description: 更新投标报价
	 * @author chenxw
	 * @param bidPriceResult
	 * @return
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean updateBidPriceResultOrSum(BidPriceResult bidPriceResult) {
		if (updateAssignProperty(bidPriceResult, new String[]{"finalBidPrice", "evaluationPrice", "modifyReason"})) {
			if (supplierOpeningResultService.updateSupplierPrice(bidPriceResult, new String[]{"finalBidPrice", "evaluationPrice", "bidPrice"}) > 0) {
				return supplierOpeningResultService.updateSumModifyReason(bidPriceResult.getTenderId(), bidPriceResult.getSupplierId());
			}
		}
		return false;
	}

	public boolean updateBidPriceAndFinalPrice(Map<String, Object> bidPriceResult) {
		return supplierOpeningResultService.updateBidPriceAndFinalPrice(bidPriceResult);
	}
	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean updateSupplierIdNotRecordedBidPrice(String tenderId , String roundId ) {
 		List<BidPriceHisResult> insertBidPriceHisResultList = new ArrayList<BidPriceHisResult>();	 
		ReBidPriceRound reBidPriceRound = reBidPriceRoundMapper.selectById(roundId);
		//获得未报价的供应商
		Map<String, String> supplierIdMap = bidPriceRoundStatusService.getSupplierBidPriceRoundComplateStatus(roundId);
		//先获取工程最新的bidprice项
		List<BidPrice> newBidPrice = bidPriceMapper.getBidPriceByTenderId(tenderId);
		//为未报价的供应商默认提交上一轮报价的结果
		supplierIdMap.forEach((supplierId,value)->{
			if(BidPriceEnum.PRICE_STATUS_UNDONE.equals(value)){
				//获取上一轮报价
				List<BidPriceHisResult> bidPriceHisResultList = bidPriceHisResultMapper.getSupplierBidPriceHisResultListByRound(tenderId , supplierId, reBidPriceRound.getRoundNo() - 1);
				//获取报价结果
				if(null == bidPriceHisResultList || bidPriceHisResultList.size() == 0) {
					bidPriceHisResultList = bidPriceHisResultMapper.getSupplierBidPriceHisResultListByRound(tenderId , supplierId, 0);
				}
				Map<String, BidPriceHisResult> bidPriceHisResultMap = bidPriceHisResultList.stream().collect(Collectors.toMap(t -> t.getSupplierId() + t.getBidPriceId(), t -> t));
				if(bidPriceHisResultMap.size() > 0) {
					newBidPrice.stream().forEach(integer -> {
						String key = supplierId + integer.getId();
						BidPriceHisResult bidPriceResultTemp = bidPriceHisResultMap.get(key);	
						if(null == bidPriceResultTemp) {
							bidPriceResultTemp  = new BidPriceHisResult();
							bidPriceResultTemp.setTenderId(tenderId);
							bidPriceResultTemp.setSupplierId(supplierId);
							bidPriceResultTemp.setBidPriceId(integer.getId());
							bidPriceResultTemp.setBidPriceName(integer.getBidPriceName());
							bidPriceResultTemp.setBidPriceType(integer.getBidPriceType());
							bidPriceResultTemp.setPriceUnit(integer.getPriceUnit());
							bidPriceResultTemp.setPriceType(integer.getPriceType());
							bidPriceResultTemp.setBidPriceId(integer.getId());
						}
						bidPriceResultTemp.setId(IDUtils.getId());
						bidPriceResultTemp.setRoundName(reBidPriceRound.getRoundName());
						bidPriceResultTemp.setBidPriceRound(reBidPriceRound.getRoundNo());
						insertBidPriceHisResultList.add(bidPriceResultTemp);
					});
				}
				bidPriceRoundStatusMapper.updateCompletePriceStatusBySupplierId(roundId, supplierId, BidPriceEnum.PRICE_STATUS_OK);
			}
		});
		if(insertBidPriceHisResultList.size()>0) {
			bidPriceHisResultMapper.insertByBatch(insertBidPriceHisResultList);
		}
		reBidPriceRound.setRoundStatus("01");
		reBidPriceRoundMapper.updateAssignProperty(reBidPriceRound, new String[] {"roundStatus"});
		// 完成当前轮次评标
		reBidPriceRoundService.completeCurrentRound(reBidPriceRound);
		//计算供应商的总价
		supplierOpeningResultService.updateSupplierSumPrice(tenderId, null, true, true);
		return true;
	}

}
