package com.gx.obe.server.management.expert.service;

import com.baomidou.mybatisplus.extension.service.IService;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

import com.gx.obe.server.management.expert.entity.ExpertEvaluationResult;
 
/** 
 * @Description: 
 * @author mazc 
 */
public interface ExpertEvaluationResultService extends IService<ExpertEvaluationResult> {
 	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeExpertEvaluationResultList 
	 */
 	Integer updateByBatch (List<ExpertEvaluationResult> ObeExpertEvaluationResultList);
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeExpertEvaluationResultList 
	 */
	Integer insertByBatch (List<ExpertEvaluationResult> ObeExpertEvaluationResultList);
	
	/**
	 * @Description: 删除所有专家为投标人的评标结果
	 * @author mazc
	 * @param tenderId 项目id
	 * @return 
	 */
	 int deleteStepByTenderId(String tenderId);

	 /**
	 * @Description: 获得评标专家对指定评标步骤对投标人的评审记录
	 * @author mazc
	 * @param tenderId
	 * @param stepId
	 * @param userId
	 * @return 
	 */
	List<ExpertEvaluationResult> getStepAllExpertEvaluationResultList(String tenderId, String stepId);
	
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param tenderId
	 * @param stepId
	 * @param supplierId
	 * @param removeMaxAndMin
	 * @return 
	 */
	List<BigDecimal> getSupplierStepAvgResult(String tenderId, String stepId, String supplierId, boolean removeMaxAndMin);
	
	
	/**
	 * @Description: 获得供应商在指定评标步骤的平均得分
	 * @author mazc
	 * @param tenderId
	 * @param stepId
	 * @param supplierId
	 * @param removeMaxAndMin
	 * @return 
	 */
	List<BigDecimal> getSupplierStepAvgResultByFactor(String tenderId, String stepId, String supplierId, boolean removeMaxAndMin);
	
	/**
	 * @Description: 获得供应商在指定评标步骤的所有专家的评标结果
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @param supplierId
	 * @return 
	 */
	List<ExpertEvaluationResult> getSupplierStepAllExpertEvaluationResultList(String tenderId, String stepId, String supplierId);
	
	/**
	 * @Description: 获得供应商在指定评标步骤的指定专家的评标结果
	 * @param tenderId
	 * @param userId
	 * @param stepId
	 * @param supplierId
	 * @return
	 */
	List<ExpertEvaluationResult> getSupplierExpertEvaluationResultList(String tenderId, String stepId, String supplierId);
	/**
	 * @Description: 删除评标专家对指定评标步骤的所有评审记录
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @param userId
	 * @return
	 */
	Integer deleteExpertEvaluationResult(String tenderId, String stepId, String userId);
	
	/**
	 * @Description: 按供应商分组获得每家供应商的评分汇总 
	 * @author wangxiang
	 * @param userId 
	 * @param stepId 
	 * @param tenderId 
	 * @return 
	 */
	List<Map<String, Object>> getSupplierSumEvaluationResultList(String tenderId, String stepId, String userId);
	/**
	 * @Description: 删除专家评审结果
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId
	 * @param userId 
	 * @return 
	 */
	boolean deleteExpertEvaluationAndFactorResult(String tenderId, String stepId, String userId);
	
	/**
	 * @Description: 删除评审结果记录
	 * @author chenxw
	 * @param tenderId
	 * @param stepId
	 * @return 
	 */
	int deleteExpertEvaluationResult(String tenderId, String stepId);
	
	

	public List<ExpertEvaluationResult> getSupplierAllEvaluationResultList(String tenderId,String supplierId);
	
	public List<ExpertEvaluationResult> getAllExpertEvaluationResultList(String tenderId );
		

	public List<ExpertEvaluationResult> getExpertSupplierEvaluationResultList(String tenderId,String supplierId ,String userId );
		
	public ExpertEvaluationResult getExpertEvaluationResult(String tenderId, String stepId, String supplierId ,String userId);
		
	
	public	List<Object> getSupplierStepAllExpertEvaluationAccessmentList(String tenderId,String supplierId ,String stepId );
	
	 List<ExpertEvaluationResult> getExpertEvaluationResult(String tenderId, String stepId, String userId);
    
}



