package com.gx.obe.server.management.expert.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.enumeration.EvaluationStepEnum;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.ObjectUtils;
import com.gx.obe.server.management.evaluation.entity.EvaluationStep;
import com.gx.obe.server.management.expert.dao.EvaluationStepExpertMapper;
import com.gx.obe.server.management.expert.entity.EvaluationStepExpert;
import com.gx.obe.server.management.expert.service.EvaluationStepExpertService;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
@Transactional
public class EvaluationStepExpertServiceImpl extends ServiceImpl<EvaluationStepExpertMapper, EvaluationStepExpert> implements EvaluationStepExpertService {

	@Autowired
	private EvaluationStepExpertMapper evaluationStepExpertMapper;
	
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeEvaluationStepExpertList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch (List<EvaluationStepExpert> ObeEvaluationStepExpertList){
		return evaluationStepExpertMapper.updateBatchList(ObeEvaluationStepExpertList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeEvaluationStepExpertList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch (List<EvaluationStepExpert> ObeEvaluationStepExpertList){
		return evaluationStepExpertMapper.insertByBatch(ObeEvaluationStepExpertList);
	}
	
	/** 
	 * @Description: 删除当前项目下所有指定的评标专家
	 * @author mazc
	 * @param tenderId 项目id
	 * @return 
	 */
	@Override
	public int deleteStepByTenderId(String tenderId) {
		QueryWrapper<EvaluationStepExpert> queryWrapper = new QueryWrapper<EvaluationStepExpert>();
		queryWrapper.lambda().eq(EvaluationStepExpert::getTenderId, tenderId);
		return evaluationStepExpertMapper.delete(queryWrapper);
	}
	
	/** 
	 * @Description: 清除为当前节点分配置的自定义专家
	 * @author chenxw
	 * @param tenderId
	 * @param stepId
	 * @return 
	 */
	@Override
	public int deleteStepByTenderIdAndStepId(String tenderId, String stepId) {
	    QueryWrapper<EvaluationStepExpert> queryWrapper = new QueryWrapper<EvaluationStepExpert>();
        queryWrapper.lambda().eq(EvaluationStepExpert::getTenderId, tenderId)
                             .eq(EvaluationStepExpert::getStepId, stepId);
        return evaluationStepExpertMapper.delete(queryWrapper);
	}
	
	/**
     * @Description: 保存评标步骤的自定义专家
     * @author chenxw
     * @param evaluationStep
     * @param stepExpertUserList 
     */
	@Override
	public void setCustomeExpert(EvaluationStep evaluationStep, List<String> stepExpertUserList){
        // 清除为当前节点分配置的自定义专家
        deleteStepByTenderIdAndStepId(evaluationStep.getTenderId(), evaluationStep.getId());
        
        // 如果选择的是自定义专家类型
        if(ObjectUtils.equals(evaluationStep.getRoleType(), EvaluationStepEnum.CUSTOM) && null != stepExpertUserList && stepExpertUserList.size() > 0){
            List<EvaluationStepExpert> evaluationStepExpertList = new ArrayList<EvaluationStepExpert>();
            for(String userId : stepExpertUserList){
                evaluationStepExpertList.add(new EvaluationStepExpert(IDUtils.getId(), evaluationStep.getTenderId(), evaluationStep.getId(), userId));
            }
            insertByBatch(evaluationStepExpertList);
        }
    }
}
