package com.gx.obe.server.management.menu.controller;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.management.menu.entity.AuthMenuFunction;
import com.gx.obe.server.management.menu.service.AuthMenuFunctionService;

import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;

 /**  
 * 
 * @author 
 * @Title: AuthMenuFunctionController  
 * @Package com.gx.obe.server.management.menu.controller   
 * @Description:   
 * @author: XiaoMa Pro - myzhichao@163.com
 * @date:   2019-05-10   
 * @version V1.0 
 * @Copyright: 2019 www.msypro.com Inc. All rights reserved. 
 *  
 */
@Api(tags = "菜单功能管理")
@RestController
@AllArgsConstructor
@RequestMapping("/menuFunction")
public class AuthMenuFunctionController extends BaseController<AuthMenuFunctionService, AuthMenuFunction> {
    
	@Autowired
	private AuthMenuFunctionService authMenuFunctionService;
	
	@GetMapping("/getMenuFunctions")
	public Map<String,String> getFunctionByMenuIdReturnMap(String menuId){
		return authMenuFunctionService.getFunctionByMenuIdReturnMap(menuId);
	}
	
	
	/**
	 * @Description: 获得最大序号
	 * @author mazc
	 * @param menuId
	 * @return 
	 */
	@GetMapping("/getMaxSortNo")
	public int getMaxSortNo(String menuId){ 
		return authMenuFunctionService.getMaxSortNo(menuId);
	}
	
	/**
	 * @Description: 是否统一编码
	 * @author mazc
	 * @param menuId
	 * @param functionId
	 * @param functionCode
	 * @return 
	 */
	@GetMapping("/isUniqueFunctionCode")
	public boolean isUniqueFunctionCode(String menuId, String functionId, String functionCode){
		return authMenuFunctionService.isUniqueFunctionCode(menuId, functionId, functionCode);
	}
	
	/**
	 * @Description: 根据menuId 查询menuFunctionList
	 * @author wangxiang
	 * @param menuId
	 * @return 
	 */
	@GetMapping("/getMenuFunctionListByMenuId")
	public List<AuthMenuFunction> getMenuFunctionListByMenuId(String menuId) {
		QueryWrapper<AuthMenuFunction>  wrapper = new QueryWrapper<AuthMenuFunction>();
		wrapper.lambda().eq(AuthMenuFunction::getMenuId, menuId).orderByAsc(AuthMenuFunction::getSortNo);
		return authMenuFunctionService.list(wrapper);
	}


	/**
	 * @Description: 批量保存或更新
	 * @author wangxiang
	 * @param menuFunctionList
	 * @return 
	 */
	@PostMapping("/insertByBatch")
	public int insertByBatch(@RequestBody List<AuthMenuFunction> menuFunctionList) {
		return authMenuFunctionService.batchSaveOrUpdate(menuFunctionList);
	}
	
	@PostMapping("/saveOrUpdate")
	public boolean saveOrUpdate(@RequestBody  AuthMenuFunction menuFunction){
		return authMenuFunctionService.saveOrUpdate(menuFunction);
	}
	
	
	/**
	 * @Description:  交换两个菜单的排序
	 * @author mazc
	 * @param sourceId
	 * @param targetId
	 * @return 
	 */
	@GetMapping("/changeResourceSortNo")
    public boolean changeResourceSortNo(String sourceId, String targetId) {
        return authMenuFunctionService.changeResourceSortNo(sourceId, targetId);
    }
	
	
}