package com.gx.obe.server.management.menu.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.enumeration.CommonEnum;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.ObjectUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.menu.dao.AuthMenuFunctionMapper;
import com.gx.obe.server.management.menu.dao.AuthMenuMapper;
import com.gx.obe.server.management.menu.entity.AuthMenuEntity;
import com.gx.obe.server.management.menu.entity.AuthMenuFunction;
import com.gx.obe.server.management.menu.service.AuthMenuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

  /**  
 * 
 * @author 
 * @Title: AuthMenuService
 * @Package com.gx.obe.server.management.menu.service  
 * @Description:     
 * @author: XiaoMa Pro - myzhichao@163.com
 * @date:   2019-05-09   
 * @version V1.0 
 * @Copyright: 2019 www.msypro.com Inc. All rights reserved. 
 *  
 */
@Service
@Transactional
public class AuthMenuServiceImpl extends ServiceImpl<AuthMenuMapper, AuthMenuEntity> implements AuthMenuService {

	@Autowired
	private AuthMenuMapper authMenuMapper;
	
	@Autowired
	private AuthMenuFunctionMapper authMenuFunctionMapper;

	@Override
	public List<AuthMenuEntity> selectUserResourceMenuList(String userId, String roleType, String useStatus) {	
		return authMenuMapper.selectUserResourceMenuList(userId, roleType, useStatus);
	}
	@Override
	public List<AuthMenuEntity> getUserRoleMenuList(String userId, String roleId, String useStatus) {	
		return authMenuMapper.getUserRoleMenuList(userId, roleId, useStatus);
	}

	/**
	 * @Description: 获得全部菜单信息(包含子菜单和父级菜单信息)
	 * @author wangxiang
	 * @param type
	 * @return 
	 */
	@Override
	public List<AuthMenuEntity> getAllResourceList(String type) {
		QueryWrapper<AuthMenuEntity> wrapper = new QueryWrapper<>();
		List<AuthMenuEntity>  menuList;
		if(null != type && type.length() > 0) {
			wrapper.lambda().eq(AuthMenuEntity::getMenuType, type);
		}
		wrapper.orderByAsc("SORT_NO");
		menuList = authMenuMapper.selectList(wrapper);
		return menuList;
	}

	/**
	 * @Description: 获得菜单的最大序号
	 * @author wangxiang
	 * @param parentId
	 * @return
	 */
	@Override
	public Integer getMaxResourceSortNo(String parentId, String menuType) {
		Integer count = authMenuMapper.getMaxResourceSortNo(parentId,menuType);
		return null != count ? count : 0;
	}

	/** 
	 * @Description: 交换两个菜单的排序
	 * @author chenxw
	 * @param sourceId
	 * @param targetId
	 * @return 
	 */
	@Override
	public boolean changeResourceSortNo(String sourceId, String targetId) {
		return authMenuMapper.changeResourceSortNo(sourceId, targetId) > 0;
	}

	/** 
	 * @Description: 批量修改指定字段
	 * @author chenxw
	 * @param menuList
	 * @param attributes
	 * @return 
	 */
	@Override
	public boolean batchUpdateProperty(List<AuthMenuEntity> menuList, String[] attributes) {
		return authMenuMapper.batchUpdateProperty(menuList, attributes) > 0;
	}

	/**
	 * @Description: 查询用户权限菜单
	 * @author wangxiang
	 * @param userId
	 * @param roleType
	 * @return
	 */
	@Override
	public List<AuthMenuEntity> getUserResourceList(String userId, String roleType) {
		return authMenuMapper.getUserResourceList(userId,roleType,CommonEnum.REAL_STATUS);
	}

	/**
	 * @Description: 根据类型获得菜单列表
	 * @author wangxiang
	 * @param menuType
	 * @return 
	 */
	@Override
	public List<AuthMenuEntity> getMenuListByMenuType(String menuType) {
		return authMenuMapper.getMenuListByMenuType(menuType);
	}

	/**
	 * @Description: 菜单编号是否唯一
	 * @author wangxiang
	 * @param menuId
	 * @param menuCode
	 * @return 
	 */
	@Override
	public boolean isUniqueMenuCode(String menuId, String menuCode) {
		if(null != menuId) {
			return authMenuMapper.isUniqueMenuCodeHasMenuId(menuId, menuCode) <= 0;
		}else {
			return authMenuMapper.isUniqueMenuCode(menuCode) <= 0;
		}
	}

	/**
	 * @Description: 根据类型获得菜单列表
	 * @author wangxiang
	 * @param menuCode
	 * @return 
	 */
	@Override
	public List<AuthMenuEntity> getMenuListByMenuCode(String menuCode) {
		List<AuthMenuEntity>  menuList = null;
		QueryWrapper<AuthMenuEntity>  wrapper = new QueryWrapper<>();
		wrapper.lambda().eq(AuthMenuEntity::getMenuCode, menuCode);
		AuthMenuEntity  authMenuEntity = authMenuMapper.selectOne(wrapper);
		if(null != authMenuEntity) {
			menuList = authMenuMapper.getMenuListByMenuType(authMenuEntity.getMenuType());
			menuList = initChildResource(menuList, authMenuEntity.getId());
		}
 		return menuList;
	}
	
	/**
	 * @Description: 菜单信息封装树节点(双重循环实现拼接)
	 * @param list
	 * @return
	 */
	private List<AuthMenuEntity> initChildResource(List<AuthMenuEntity> list, String parentId){
		List<AuthMenuEntity> menuList = null;
		if(null != list && list.size() > 0){
			menuList = new ArrayList<>();
			for(AuthMenuEntity parentMenu : list){
				for(AuthMenuEntity subResource : list){
					if(StringUtils.isNotEmpty(subResource.getParentId()) && parentMenu.getId().equals(subResource.getParentId())){
						parentMenu.addChild(subResource);
						subResource.setParentMenu(parentMenu);
					}
				}
				if(ObjectUtils.equals(ObjectUtils.getObjString(parentId), ObjectUtils.getObjString(parentMenu.getParentId()))){
					menuList.add(parentMenu);
				}
			}
		}
		return menuList;
	}

	/**
	 * @Description: 获得菜单下的功能集
	 * @author wangxiang
	 * @param menuId
	 * @return 
	 */
	@Override
	public Map<String, String> getMenuFunctionMap(String menuId) {
		List<Map<String, Object>>  functionMapList = authMenuMapper.getMenuFunctionMap(menuId);
		Map<String, String> menuFunctionMap = null;
		if(null != functionMapList && functionMapList.size() > 0){
			menuFunctionMap = new HashMap<>();
			for(Map<String, Object> map : functionMapList){
				menuFunctionMap.put((String)map.get("FUNCTION_CODE"), (String)map.get("FUNCTION_STATUS"));
			}
		}
		return menuFunctionMap;
	}

	@Override
	public AuthMenuEntity saveOrUpdateNoEmptyReturn(AuthMenuEntity menu) {
		if(null == menu) {
			return null;
		}
		if(StringUtils.isNotEmpty(menu.getId())) {
			int size = authMenuMapper.updateById(menu);
			if(size > 0) {
				return authMenuMapper.selectById(menu.getId());
			}
			return menu;
		}else {
			menu.setId(IDUtils.getId());
			authMenuMapper.insert(menu);
			return menu;
		}
	}

	@Override
	public boolean updateAssignProperty(AuthMenuEntity menu) {
		return authMenuMapper.updateById(menu) > 0;
	}

	@Override
	public AuthMenuEntity getMenuByMenuCode(String menuCode) {
		QueryWrapper<AuthMenuEntity>  wrapper = new QueryWrapper<>();
		wrapper.lambda().eq(AuthMenuEntity::getMenuCode, menuCode);
		return authMenuMapper.selectOne(wrapper);
	}
	
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer deleteByMenuId(String menuId) {
		// 删除菜单
		QueryWrapper<AuthMenuEntity>  wrapper = new QueryWrapper<>();
		wrapper.lambda().eq(AuthMenuEntity::getId, menuId);
		// 删除按钮
		QueryWrapper<AuthMenuFunction>  wrapperMenuFunction = new QueryWrapper<>();
		wrapperMenuFunction.lambda().eq(AuthMenuFunction::getMenuId, menuId);
		if(authMenuMapper.delete(wrapper) > 0) {
			authMenuFunctionMapper.delete(wrapperMenuFunction);
			return 1;
		}
		return 0;
 	}
 

}
