package com.gx.obe.server.management.negotiation.controller;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.management.evaluation.entity.EvaluationStep;
import com.gx.obe.server.management.negotiation.entity.Negotiation;
import com.gx.obe.server.management.negotiation.entity.NegotiationResult;
import com.gx.obe.server.management.negotiation.service.NegotiationService;
import com.gx.obe.server.management.supplier.entity.SupplierEvaluationStep;
import com.gx.obe.server.management.vo.SaveNegotiationResultVo;

import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;
/** 
 * @Description: 
 * @author mazc 
 */
@Api(tags = "")
@RestController
@AllArgsConstructor
@RequestMapping("/obeNegotiation")
public class NegotiationController extends BaseController<NegotiationService,Negotiation>{
	@Autowired
	public NegotiationService negotiationServices;
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeNegotiationList 
	 */
	@PostMapping("/insertByBatch")
	public int insertByBatch(@RequestBody List<Negotiation> ObeNegotiationList) {
		return negotiationServices.insertByBatch(ObeNegotiationList);
	}
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeNegotiationList 
	 */
	@PostMapping("/updateByBatch")
	public int updateByBatch(@RequestBody List<Negotiation> ObeNegotiationList) {
		return negotiationServices.updateByBatch(ObeNegotiationList);
	}
	
	/**
	 * @Description: 获得竞争性谈判评标结果
	 * @param tenderId 项目ID编号
	 * @param stepId 项目评标步骤ID编号
	 * @param supplierId 投标人ID编号
	 * @return List<NegotiationResult>
	 */
	public List<NegotiationResult> getEvalNegotiationResult(String tenderId, String stepId, String supplierId){
		return negotiationServices.getEvalNegotiationResult(tenderId,stepId,supplierId);
	}
	
	/**
	 * @Description: 保存竞争性谈判评标结果
	 * @param tenderId 项目ID编号
	 * @param userId 用户ID编号
	 * @param evaluationStep 项目评标步骤（评标步骤）
	 * @param nodeNegotiationResultList 评审竞争性谈判指标结果
	 * @param supplierEvalNodeList 投标人评标步骤
	 * @return boolean
	 */
	public boolean saveNegotiationResult(@RequestBody SaveNegotiationResultVo saveNegotiationResultVo){
		String tenderId = saveNegotiationResultVo.getTenderId();
		String userId = saveNegotiationResultVo.getUserId();
		EvaluationStep evaluationStep = saveNegotiationResultVo.getEvaluationStep();
		List<NegotiationResult> nodeNegotiationResultList = saveNegotiationResultVo.getNodeNegotiationResultList();
		List<SupplierEvaluationStep> supplierEvalNodeList = saveNegotiationResultVo.getSupplierEvalNodeList();
		
		return negotiationServices.saveNegotiationResult(tenderId,userId,evaluationStep,nodeNegotiationResultList,supplierEvalNodeList);
	}

	
	/**
	 * @Description: 提交竞争性谈判评标结果
	 * @param tenderId 项目ID编号
	 * @param userId 用户ID编号
	 * @param evaluationStep 项目评标步骤（评标步骤）
	 * @return boolean
	 */
	public boolean submitNegotiationResult(@RequestBody SaveNegotiationResultVo saveNegotiationResultVo){
		String tenderId = saveNegotiationResultVo.getTenderId();
		String userId = saveNegotiationResultVo.getUserId();
		EvaluationStep evaluationStep = saveNegotiationResultVo.getEvaluationStep();
		return negotiationServices.submitNegotiationResult(tenderId,userId,evaluationStep);

	}
}