package com.gx.obe.server.management.other.controller;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.management.other.entity.SignatureFile;
import com.gx.obe.server.management.other.entity.SignatureUser;
import com.gx.obe.server.management.other.service.SignatureUserService;
import com.gx.obe.server.management.vo.UpdateAssignPropertyVo;

import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;
/** 
 * @Description: 
 * @author mazc 
 */
@Api(tags = "")
@RestController
@AllArgsConstructor
@RequestMapping("/signatureUser")
public class SignatureUserController extends BaseController<SignatureUserService,SignatureUser>{
	@Autowired
	public SignatureUserService signatureUserServices;
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeSignatureUserList 
	 */
	@PostMapping("/insertByBatch")
	public int insertByBatch(@RequestBody List<SignatureUser> ObeSignatureUserList) {
		return signatureUserServices.insertByBatch(ObeSignatureUserList);
	}
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeSignatureUserList 
	 */
	@PostMapping("/updateByBatch")
	public int updateByBatch(@RequestBody List<SignatureUser> ObeSignatureUserList) {
		return signatureUserServices.updateByBatch(ObeSignatureUserList);
	}
	
	
	/**
	 * @Description: 获得当前用户需要签章的报表
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @return 
	 */
	@GetMapping("/getUserSignatureFileList")
	public List<SignatureUser> getUserSignatureFileList(String tenderId, String userId){
		return signatureUserServices.getUserSignatureFileList(tenderId, userId);
	}
	
	/**
	 * @Description: 获得当前用户需要签章信息
	 * @author mazc
	 * @param id
	 * @return 
	 */
	@GetMapping("/getSignatureUserById")
	public SignatureUser getSignatureUserById(String id){
		return signatureUserServices.getSignatureUserById(id);
	}
	
	/**
	 * @Description: 修改用户签章状态
	 * @author mazc
	 * @param id
	 * @param signatureType
	 * @param signatureTime
	 * @return 
	 */
	@GetMapping("/updateSignatureUser")
	public boolean updateSignatureUser(String id, String signatureType, Date signatureTime){
		return signatureUserServices.updateSignatureUser(id, signatureType, signatureTime);
	}

	@GetMapping("/getSignatureUserBySignatureId")
	public List<SignatureUser> getSignatureUserBySignatureId(String signatureId){
		return signatureUserServices.getSignatureUserBySignatureId(signatureId);
	}
	
	@PostMapping("/updateAssignProperty")
	public boolean updateAssignProperty(@RequestBody UpdateAssignPropertyVo<SignatureUser> updateAssignPropertyVo) {
		SignatureUser signatureUser = updateAssignPropertyVo.getEntity();
		String[] attributes = updateAssignPropertyVo.getAttributes();
		return signatureUserServices.updateAssignProperty(signatureUser, attributes);
	}
	
	/**
	 * @Description: 通过用户名修改用户签章状态
	 * @author guoyr
	 * @param id
	 * @param userName
	 * @param signatureType
	 * @return 
	 */
	@GetMapping("/updateSignatureTypeByUserName")
	public boolean updateSignatureTypeByUserName(String signatureId, String userName, String signatureType){
		return signatureUserServices.updateSignatureTypeByUserName(signatureId, userName, signatureType);
	}
}