package com.gx.obe.server.management.price.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.enumeration.BidPriceEnum;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.price.dao.BidPriceRoundStatusMapper;
import com.gx.obe.server.management.price.dao.ReBidPriceRoundMapper;
import com.gx.obe.server.management.price.entity.BidPriceRoundStatus;
import com.gx.obe.server.management.price.entity.ReBidPriceRound;
import com.gx.obe.server.management.price.service.BidPriceRoundStatusService;
import com.gx.obe.server.management.price.service.ReBidPriceRoundService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
@Transactional
public class BidPriceRoundStatusServiceImpl extends ServiceImpl<BidPriceRoundStatusMapper, BidPriceRoundStatus> implements BidPriceRoundStatusService {

	@Autowired
	private BidPriceRoundStatusMapper bidPriceRoundStatusMapper;
	
	
	@Autowired
	private ReBidPriceRoundMapper reBidPriceRoundMapper;
	
	@Autowired
	private ReBidPriceRoundService reBidPriceRoundService;
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeBidPriceRoundStatusList 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch(List<BidPriceRoundStatus> ObeBidPriceRoundStatusList) {
		return bidPriceRoundStatusMapper.updateBatchList(ObeBidPriceRoundStatusList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeBidPriceRoundStatusList 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch(List<BidPriceRoundStatus> ObeBidPriceRoundStatusList) {
		return bidPriceRoundStatusMapper.insertByBatch(ObeBidPriceRoundStatusList);
	}
	
	/**
     * @Description: 指定字段修改
     * @author chenxw
     * @param BidPriceRoundStatus
	 * @param attributes
     */
	@Override
    public boolean updateAssignProperty(BidPriceRoundStatus BidPriceRoundStatus, String[] attributes) {
		return bidPriceRoundStatusMapper.updateAssignProperty(BidPriceRoundStatus, attributes) > 0;
	}
    
    /**
     * @Description: 批量指定字段修改
     * @author chenxw
     * @param ObeBidPriceRoundStatusList
	 * @param attributes
     */
	@Override
    public Integer batchUpdateProperty(List<BidPriceRoundStatus> ObeBidPriceRoundStatusList, String[] attributes) {
		return bidPriceRoundStatusMapper.batchUpdateProperty(ObeBidPriceRoundStatusList, attributes);
	}
	
	/** 
	 * @Description: 批量添加或跟新
	 * @author chenxw
	 * @param ObeBidPriceRoundStatusList
	 * @param attributes
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
    public Integer batchSaveOrUpdate(List<BidPriceRoundStatus> ObeBidPriceRoundStatusList, String[] attributes) {
        List<BidPriceRoundStatus> insertObeBidPriceRoundStatusList = new ArrayList<>();
        List<BidPriceRoundStatus> updateObeBidPriceRoundStatusList = new ArrayList<>();
        for (BidPriceRoundStatus BidPriceRoundStatus : ObeBidPriceRoundStatusList) {
            if (StringUtils.isEmpty(BidPriceRoundStatus.getId())) {
                BidPriceRoundStatus.setId(IDUtils.getId());
                insertObeBidPriceRoundStatusList.add(BidPriceRoundStatus);
            } else {
                updateObeBidPriceRoundStatusList.add(BidPriceRoundStatus);
            }
        }
        int count = 0;
        if (insertObeBidPriceRoundStatusList.size() > 0) {
            count += bidPriceRoundStatusMapper.insertByBatch(insertObeBidPriceRoundStatusList);
        }
        if (updateObeBidPriceRoundStatusList.size() > 0) {
            count +=bidPriceRoundStatusMapper.batchUpdateProperty(updateObeBidPriceRoundStatusList, attributes);
        }
        return count;
    }

	@Override
	public boolean isCompletePrice(String strRoundId) {
		QueryWrapper<BidPriceRoundStatus> queryWrapper = new QueryWrapper<BidPriceRoundStatus>();
		queryWrapper.lambda().eq(BidPriceRoundStatus::getPriceRoundId, strRoundId).eq(BidPriceRoundStatus::getPriceStatus, BidPriceEnum.PRICE_STATUS_UNDONE);	
		QueryWrapper<ReBidPriceRound> queryReBidPriceRound = new QueryWrapper<ReBidPriceRound>();
		queryReBidPriceRound.lambda().eq(ReBidPriceRound::getId, strRoundId);
		ReBidPriceRound round  = reBidPriceRoundService.getOne(queryReBidPriceRound);
		return  bidPriceRoundStatusMapper.selectList(queryWrapper).size() == 0 && BidPriceEnum.PRICE_STATUS_OK.equals(round.getRoundStatus());
 	}

	@Override
	public int getNotCompletePriceNumber(String strRoundId) {
		QueryWrapper<BidPriceRoundStatus> queryWrapper = new QueryWrapper<BidPriceRoundStatus>();
		queryWrapper.lambda().eq(BidPriceRoundStatus::getPriceRoundId, strRoundId).eq(BidPriceRoundStatus::getPriceStatus, BidPriceEnum.PRICE_STATUS_UNDONE);	
 		return bidPriceRoundStatusMapper.selectList(queryWrapper).size();
	}

	@Override
	public int getCompletePriceNumber(String strRoundId) {
		QueryWrapper<BidPriceRoundStatus> queryWrapper = new QueryWrapper<BidPriceRoundStatus>();
		queryWrapper.lambda().eq(BidPriceRoundStatus::getPriceRoundId, strRoundId).eq(BidPriceRoundStatus::getPriceStatus, BidPriceEnum.PRICE_STATUS_OK);	
 		return bidPriceRoundStatusMapper.selectList(queryWrapper).size();
	}

	@Override
	public boolean isCompletePriceBySupplier(String strRoundId, String supplier) {
		QueryWrapper<BidPriceRoundStatus> queryWrapper = new QueryWrapper<BidPriceRoundStatus>();
		queryWrapper.lambda().eq(BidPriceRoundStatus::getPriceRoundId, strRoundId)
					.eq(BidPriceRoundStatus::getPriceStatus, BidPriceEnum.PRICE_STATUS_UNDONE)
					.eq(BidPriceRoundStatus::getSupplierId, supplier);	
 		return bidPriceRoundStatusMapper.selectList(queryWrapper).size() == 0;
	}

	@Override
	public boolean updateCompletePriceStatusBySupplierId(String strRoundId, String supplier,String status) {
		return bidPriceRoundStatusMapper.updateCompletePriceStatusBySupplierId(strRoundId, supplier, status) > 0;
	}
	
	public Map<String, String> getSupplierBidPriceRoundComplateStatus(String strRoundId){
		Map<String,String>  resultMap = new HashMap<String, String>();
		QueryWrapper<BidPriceRoundStatus> queryWrapper = new QueryWrapper<BidPriceRoundStatus>();
		queryWrapper.lambda().eq(BidPriceRoundStatus::getPriceRoundId, strRoundId);
		List<BidPriceRoundStatus> list = bidPriceRoundStatusMapper.selectList(queryWrapper);
		if(null != list) {
			for( BidPriceRoundStatus bidPriceRoundStatus : list) {
				resultMap.put(bidPriceRoundStatus.getSupplierId(),bidPriceRoundStatus.getPriceStatus());
			}
		}
		return resultMap;
	}

	@Override
	public boolean updateCompletePriceStatus(String roundId, String status) {
		boolean isUpdate = bidPriceRoundStatusMapper.updateCompletePriceStatus(roundId, status) > 0;
		if(isUpdate) {
			reBidPriceRoundMapper.updateRoundStatus(roundId,"01");
			// 完成当前轮次评标
			ReBidPriceRound reBidPriceRound = reBidPriceRoundMapper.selectById(roundId);
			reBidPriceRoundService.completeCurrentRound(reBidPriceRound);
		}
		return isUpdate;
	}

	/**
	 * @Description: 根据轮次Id及供应商Id获取数据
	 * @author chenxw
	 * @param priceRoundId
	 * @param supplierId
	 * @return
	 */
	@Override
	public BidPriceRoundStatus getBidPriceRoundStatus(String priceRoundId, String supplierId) {
		QueryWrapper<BidPriceRoundStatus> queryWrapper = new QueryWrapper<>();
		queryWrapper.lambda()
				.eq(BidPriceRoundStatus::getPriceRoundId, priceRoundId)
				.eq(BidPriceRoundStatus::getSupplierId, supplierId);
		return bidPriceRoundStatusMapper.selectOne(queryWrapper);
	}

	@Override
	public Map<String, String> getBidPriceRoundComplateStatus(String tenderId){
		ReBidPriceRound reBidPriceRound = reBidPriceRoundMapper.getMaxRoundInfo(tenderId);
		Map<String,String>  resultMap = new HashMap<String, String>();
		if(null == reBidPriceRound) {
			resultMap.put("id", "01");
			return resultMap;
		}
		QueryWrapper<BidPriceRoundStatus> queryWrapper = new QueryWrapper<BidPriceRoundStatus>();
		queryWrapper.lambda().eq(BidPriceRoundStatus::getPriceRoundId, reBidPriceRound.getId());
		List<BidPriceRoundStatus> list = bidPriceRoundStatusMapper.selectList(queryWrapper);
		if(null != list) {
			for( BidPriceRoundStatus bidPriceRoundStatus : list) {
				resultMap.put(bidPriceRoundStatus.getSupplierId(),bidPriceRoundStatus.getPriceStatus());
			}
		}
		return resultMap;
	}
	
	@Override
	public boolean isCompletePriceByRoundId(String strRoundId) {
		QueryWrapper<BidPriceRoundStatus> queryWrapper = new QueryWrapper<BidPriceRoundStatus>();
		queryWrapper.lambda().eq(BidPriceRoundStatus::getPriceRoundId, strRoundId).eq(BidPriceRoundStatus::getPriceStatus, BidPriceEnum.PRICE_STATUS_UNDONE);	
		return  bidPriceRoundStatusMapper.selectList(queryWrapper).size() == 0;
 	}

	@Override
	public void updateRoundStatus(ReBidPriceRound reBidPriceRound) {
		if(isCompletePriceByRoundId(reBidPriceRound.getId())) {
			reBidPriceRound.setRoundStatus("01");
			reBidPriceRoundMapper.updateAssignProperty(reBidPriceRound, new String[]{"id","roundStatus"});
		}	
	}
}
