package com.gx.obe.server.management.struct_new.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.struct_new.dao.ObeCertificateMapper;
import com.gx.obe.server.management.struct_new.entity.ObeCertificate;
import com.gx.obe.server.management.struct_new.service.ObeCertificateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * @author mazc
 * @Description:
 */
@Service
@Transactional
public class ObeCertificateServiceImpl extends ServiceImpl<ObeCertificateMapper, ObeCertificate> implements ObeCertificateService {

    @Autowired
    private ObeCertificateMapper obeCertificateMapper;

    /**
     * @param ObeCertificateList
     * @Description: 批量更新
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer updateByBatch(List<ObeCertificate> ObeCertificateList) {
        return obeCertificateMapper.updateBatchList(ObeCertificateList);
    }

    /**
     * @param ObeCertificateList
     * @Description: 批量插入
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer insertByBatch(List<ObeCertificate> ObeCertificateList) {
        return obeCertificateMapper.insertByBatch(ObeCertificateList);
    }

    /**
     * @param ObeCertificate
     * @param attributes
     * @Description: 指定字段修改
     * @author chenxw
     */
    @Override
    public boolean updateAssignProperty(ObeCertificate ObeCertificate, String[] attributes) {
        return obeCertificateMapper.updateAssignProperty(ObeCertificate, attributes) > 0;
    }

    /**
     * @param ObeCertificateList
     * @param attributes
     * @Description: 批量指定字段修改
     * @author chenxw
     */
    @Override
    public Integer batchUpdateProperty(List<ObeCertificate> ObeCertificateList, String[] attributes) {
        return obeCertificateMapper.batchUpdateProperty(ObeCertificateList, attributes);
    }

    /**
     * @param ObeCertificateList
     * @param attributes
     * @return
     * @Description: 批量添加或跟新
     * @author chenxw
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer batchSaveOrUpdate(List<ObeCertificate> ObeCertificateList, String[] attributes) {
        List<ObeCertificate> insertObeCertificateList = new ArrayList<>();
        List<ObeCertificate> updateObeCertificateList = new ArrayList<>();
        for (ObeCertificate ObeCertificate : ObeCertificateList) {
            if (StringUtils.isEmpty(ObeCertificate.getId())) {
                ObeCertificate.setId(IDUtils.getId());
                insertObeCertificateList.add(ObeCertificate);
            } else {
                updateObeCertificateList.add(ObeCertificate);
            }
        }
        int count = 0;
        if (insertObeCertificateList.size() > 0) {
            count += obeCertificateMapper.insertByBatch(insertObeCertificateList);
        }
        if (updateObeCertificateList.size() > 0) {
            count += obeCertificateMapper.batchUpdateProperty(updateObeCertificateList, attributes);
        }
        return count;
    }

    /**
     * @param projectLeaderId
     * @return
     * @Description: 获取证书列表
     * @author chenxw
     */
    public List<ObeCertificate> getCertificateList(String projectLeaderId) {
        QueryWrapper<ObeCertificate> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ObeCertificate::getProjectLeaderId, projectLeaderId);
        return obeCertificateMapper.selectList(queryWrapper);
    }

}
