package com.gx.obe.server.management.supplier.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.management.supplier.dao.AreaSupplierMapper;
import com.gx.obe.server.management.supplier.entity.AreaSupplier;
import com.gx.obe.server.management.supplier.service.AreaSupplierService;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
public class AreaSupplierServiceImpl extends ServiceImpl<AreaSupplierMapper, AreaSupplier> implements AreaSupplierService {

	@Autowired
	private AreaSupplierMapper areaSupplierMapper;
	
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param AreaSupplierList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch (List<AreaSupplier> AreaSupplierList){
		return areaSupplierMapper.updateBatchList(AreaSupplierList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param AreaSupplierList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch (List<AreaSupplier> AreaSupplierList){
		return areaSupplierMapper.insertByBatch(AreaSupplierList);
	}

	/** 
	 * @Description: 判断区内企业是否存在
	 * @author mazc
	 * @param areaSupplierName
	 * @param supplierType
	 * @return 
	 */
	@Override
	public boolean hasSupplier(String areaSupplierName, String supplierType) {
		return areaSupplierMapper.hasSupplier(areaSupplierName, supplierType) > 0;
	}

	/** 
	 * @Description: 通过名字获取区内企业
	 * @author mazc
 	 * @return 
	 */
	@Override
	public List<AreaSupplier> getAreaSupplierListByName() {
		QueryWrapper<AreaSupplier> queryWrapper = new QueryWrapper<AreaSupplier>();
		return areaSupplierMapper.selectList(queryWrapper);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public String saveDownLoadAreaSupplier(AreaSupplier areaSupplier) {
 		StringBuffer buffer = new StringBuffer();
 			//判断当前供应商是否意见存在，如果存在，则供应商已经有独立id
			if(null != areaSupplier.getId() && !"".equals(areaSupplier.getId())){
				int result = areaSupplierMapper.updateById(areaSupplier);
				if(result == 1){
					buffer.append("√ [" +areaSupplier.getAreaSupplierName()+"] 信息更新成功！");
				}else{
					buffer.append("× [" +areaSupplier.getAreaSupplierName()+"] 信息更新失败！");
				}
			}else{
				areaSupplier.setId(IDUtils.getId());
				int result = areaSupplierMapper.insert(areaSupplier);
				if(result == 1){
					buffer.append("√ [" +areaSupplier.getAreaSupplierName()+"] 下载成功！");
				}else{
					buffer.append("× [" +areaSupplier.getAreaSupplierName()+"] 下载失败！");
				}
			}
		return buffer.toString();
	}
	

}
