package com.gx.obe.server.management.task.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.task.dao.ObeTaskMapper;
import com.gx.obe.server.management.task.entity.ObeTask;
import com.gx.obe.server.management.task.service.ObeTaskService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * @author mazc
 * @Description:
 */
@Service
@Transactional
public class ObeTaskServiceImpl extends ServiceImpl<ObeTaskMapper, ObeTask> implements ObeTaskService {

    private final ObeTaskMapper obeTaskMapper;

    @Autowired
    public ObeTaskServiceImpl(ObeTaskMapper obeTaskMapper) {
        this.obeTaskMapper = obeTaskMapper;
    }

    /**
     * @param ObeTaskList
     * @Description: 批量更新
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer updateByBatch(List<ObeTask> ObeTaskList) {
        return obeTaskMapper.updateBatchList(ObeTaskList);
    }

    /**
     * @param ObeTaskList
     * @Description: 批量插入
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer insertByBatch(List<ObeTask> ObeTaskList) {
        return obeTaskMapper.insertByBatch(ObeTaskList);
    }

    /**
     * @param ObeTask
     * @param attributes
     * @Description: 指定字段修改
     * @author chenxw
     */
    @Override
    public boolean updateAssignProperty(ObeTask ObeTask, String[] attributes) {
        return obeTaskMapper.updateAssignProperty(ObeTask, attributes) > 0;
    }

    /**
     * @param ObeTaskList
     * @param attributes
     * @Description: 批量指定字段修改
     * @author chenxw
     */
    @Override
    public Integer batchUpdateProperty(List<ObeTask> ObeTaskList, String[] attributes) {
        return obeTaskMapper.batchUpdateProperty(ObeTaskList, attributes);
    }

    /**
     * @param ObeTaskList
     * @param attributes
     * @return
     * @Description: 批量添加或跟新
     * @author chenxw
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer batchSaveOrUpdate(List<ObeTask> ObeTaskList, String[] attributes) {
        List<ObeTask> insertObeTaskList = new ArrayList<>();
        List<ObeTask> updateObeTaskList = new ArrayList<>();
        for (ObeTask ObeTask : ObeTaskList) {
            if (StringUtils.isEmpty(ObeTask.getId())) {
                ObeTask.setId(IDUtils.getId());
                insertObeTaskList.add(ObeTask);
            } else {
                updateObeTaskList.add(ObeTask);
            }
        }
        int count = 0;
        if (insertObeTaskList.size() > 0) {
            count += obeTaskMapper.insertByBatch(insertObeTaskList);
        }
        if (updateObeTaskList.size() > 0) {
            count += obeTaskMapper.batchUpdateProperty(updateObeTaskList, attributes);
        }
        return count;
    }

    /**
     * @param userId
     * @return
     * @Description: 获取待办列表
     * @author chenxw
     */
    @Override
    public List<ObeTask> getTaskList(String userId, String state) {
        return obeTaskMapper.getTaskList(userId, state);
    }

    /**
     * @param userId
     * @return
     * @Description: 获取代办数量
     * @author chenxw
     */
    @Override
    public Integer getTaskCount(String userId, String state) {
        QueryWrapper<ObeTask> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ObeTask::getExecutorUserId, userId).eq(ObeTask::getState, state);
        return obeTaskMapper.selectCount(queryWrapper);
    }

    /**
     * @param taskId
     * @param state
     * @Description: 修改待办状态
     * @author chenxw
     */
    @Override
    public void updateTaskState(String taskId, String state) {
        UpdateWrapper<ObeTask> updateWrapper = new UpdateWrapper<>();
        updateWrapper.lambda().set(ObeTask::getState, state).eq(ObeTask::getId, taskId);
        obeTaskMapper.update(null, updateWrapper);
    }

}
