package com.gx.obe.server.management.user.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.management.supplier.dao.SupplierEvaluationResultMapper;
import com.gx.obe.server.management.user.dao.AuthLoginRecordMapper;
import com.gx.obe.server.management.user.entity.AuthLoginRecordEntity;
import com.gx.obe.server.management.user.service.AuthLoginRecordService;

  /**  
 * 
 * @author 
 * @Title: AuthLoginRecordService
 * @Package com.gx.obe.server.management.user.service  
 * @Description:     
 * @author: XiaoMa Pro - myzhichao@163.com
 * @date:   2019-05-08   
 * @version V1.0 
 * @Copyright: 2019 www.msypro.com Inc. All rights reserved. 
 *  
 */
@Service
@Transactional
public class AuthLoginRecordServiceImpl extends ServiceImpl<AuthLoginRecordMapper, AuthLoginRecordEntity> implements AuthLoginRecordService {

	@Autowired
	private AuthLoginRecordMapper authLoginRecordMapper;
	
	@Autowired
	private SupplierEvaluationResultMapper supplierEvaluationResultMapper;
	
	 /**   
	 * @Title: deleteAccountByLoginInfo   
	 * @Description:  通过登陆户账号 登陆类型删除信息
	 * @param: @param userAccount
	 * @param: @param loginSysType      
	 * @return: void      
	 * @throws   
	 */  
	public void deleteAccountByLoginInfo(String userAccount , String loginSysType){
		QueryWrapper<AuthLoginRecordEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.lambda().eq(AuthLoginRecordEntity::getUserAccount, userAccount).eq(AuthLoginRecordEntity::getLoginSysType, loginSysType);
		authLoginRecordMapper.delete(queryWrapper);
	}

	@Override
	public int insert(AuthLoginRecordEntity authLoginRecordEntity) {
		return authLoginRecordMapper.insert(authLoginRecordEntity);
	}

	/** 
	 * @Description: 根据项目id获取项目经理登录信息
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	@Override
	public AuthLoginRecordEntity getLoginRecordByTenderId(String tenderId) {
		return authLoginRecordMapper.getLoginRecordByTenderId(tenderId);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public void logout(String account, String sysType, String loginRecordId,String applyUserId) {
		authLoginRecordMapper.logout(account, sysType, loginRecordId);
		// 退出地释放申请填写供应商评废标意见的独占资源
		supplierEvaluationResultMapper.updateApplyUserIdByUserId(applyUserId);
	}

	/** 
	 * @Description: 获得评标室已登录的专家记录
	 * @author mazc
	 * @param evaluationRoomId
	 * @return 
	 */
	@Override
	public List<AuthLoginRecordEntity> getLoginRecordByEvalBidRoomId(String evaluationRoomId) {
		return authLoginRecordMapper.getLoginRecordByEvalBidRoomId(evaluationRoomId);
	}

	@Override
	public List<AuthLoginRecordEntity> getLoginRecordAllList() {
		QueryWrapper<AuthLoginRecordEntity> queryWrapper = new QueryWrapper<>();
		return authLoginRecordMapper.selectList(queryWrapper);
	}

	/** 
	 * @Description:  是否已被注销
	 * @author mazc
	 * @param account
	 * @param sysType
	 * @param loginRecordId
	 * @return 
	 */
	@Override
	public boolean isLogout(String account, String sysType, String loginRecordId) {
		return authLoginRecordMapper.isLogout(account, sysType, loginRecordId) == 0;
	}
}
	