package com.gx.obe.server.management.user.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.management.user.dao.AuthUserRoleMapper;
import com.gx.obe.server.management.user.entity.AuthRoleEntity;
import com.gx.obe.server.management.user.entity.AuthUserRoleEntity;
import com.gx.obe.server.management.user.service.AuthRoleService;
import com.gx.obe.server.management.user.service.AuthUserRoleService;

  /**  
 * 
 * @author 
 * @Title: IAuthUserRoleService
 * @Package com.gx.obe.server.management.user.service  
 * @Description:     
 * @author: XiaoMa Pro - myzhichao@163.com
 * @date:   2019-04-29   
 * @version V1.0 
 * @Copyright: 2019 www.msypro.com Inc. All rights reserved. 
 *  
 */
@Service
public class AuthUserRoleServiceImpl extends ServiceImpl<AuthUserRoleMapper, AuthUserRoleEntity> implements AuthUserRoleService {
	@Autowired
	private AuthUserRoleMapper authUserRoleMapper;
	@Autowired
	private AuthRoleService authRoleService;
	@Override
	public int batchCreateSave(List<AuthUserRoleEntity> ROLE_LIST) {
		return authUserRoleMapper.insertByBatch(ROLE_LIST);
	}

	@Override
	public int initUserRole(String userId, String roleCode,String createUserId) {
		List<AuthUserRoleEntity> userRoleList = new ArrayList<AuthUserRoleEntity>();
		Date nowDate = new Date();
		boolean hasUserRole = authUserRoleMapper.hasUserRole(userId, roleCode) > 0;
		if(!hasUserRole){
			// 分配角色
			List<AuthRoleEntity> roleList = authRoleService.getRoleListByRoleCode(new String[]{roleCode});
			if(null != roleList && roleList.size() > 0){
				for(AuthRoleEntity role : roleList){
					AuthUserRoleEntity userRole = new AuthUserRoleEntity();
					userRole.setId(IDUtils.getId());
					userRole.setRoleId(role.getId());
					userRole.setUserId(userId);
					userRole.setCreateTime(nowDate);
					userRole.setCreateUserId(createUserId);
					userRoleList.add(userRole);
				}
			}
		}
		if(userRoleList.size() > 0){
			return	authUserRoleMapper.insertByBatch(userRoleList);
		}
		return 0;
	}

	/** 
	 * @Description:  获得用户拥有的角色Id
	 * @author mazc
	 * @param userId
	 * @return 
	 */
	@Override
	public List<String> getUserRoleIdList(String userId) {
		return authUserRoleMapper.getUserRoleIdList(userId);
	}

	@Override
	@Transactional(rollbackFor = Exception.class) 
	public boolean authorizedRoleForUser(String userId, List<AuthRoleEntity> roleList, String curUserIs) {
		QueryWrapper<AuthUserRoleEntity> queryWrapper = new QueryWrapper<AuthUserRoleEntity>();
		queryWrapper.lambda().eq(AuthUserRoleEntity::getUserId, userId);
		authUserRoleMapper.delete(queryWrapper);
		if(null != roleList && roleList.size() > 0){
			List<AuthUserRoleEntity> userRoleList = new ArrayList<AuthUserRoleEntity>();
			for(AuthRoleEntity role : roleList){
				if(null != role){
					AuthUserRoleEntity userRole = new AuthUserRoleEntity();
					userRole.setId(IDUtils.getId());
					userRole.setCreateUserId(curUserIs);
					userRole.setCreateTime(new Date());
					userRole.setRoleId(role.getId());
					userRole.setUserId(userId);
					userRoleList.add(userRole);
				}
			}
			// 为用户批量授权
			return authUserRoleMapper.insertByBatch(userRoleList) > 0;
		}
		return true;
	}

}
